# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023LimsProject(str, Enum):
    """
    Enum class for LIMSProject.
    """

    """
    allowed enum values
    """
    N_0200 = '0200'
    N_0309 = '0309'
    N_0310 = '0310'
    N_0311 = '0311'
    N_0312 = '0312'
    N_0314 = '0314'
    N_0316 = '0316'
    N_0319 = '0319'
    N_0320 = '0320'
    N_0321 = '0321'
    N_03212 = '03212'
    N_03213 = '03213'
    N_03214 = '03214'
    N_0322 = '0322'
    N_0324 = '0324'
    N_0325 = '0325'
    N_0326 = '0326'
    N_0327 = '0327'
    N_03272 = '03272'
    N_0328 = '0328'
    N_0329 = '0329'
    N_0331 = '0331'
    N_0334 = '0334'
    N_03342 = '03342'
    N_0335 = '0335'
    N_0336 = '0336'
    N_0338 = '0338'
    N_0339 = '0339'
    N_03392 = '03392'
    N_0340 = '0340'
    N_0342 = '0342'
    N_03422 = '03422'
    N_0343 = '0343'
    N_0344 = '0344'
    N_0345 = '0345'
    N_0346 = '0346'
    N_0350 = '0350'
    N_0350X = '0350x'
    N_0351 = '0351'
    N_0351X = '0351x'
    N_0354 = '0354'
    N_0355 = '0355'
    N_0357 = '0357'
    N_0358 = '0358'
    N_0359 = '0359'
    N_0360 = '0360'
    N_03602 = '03602'
    N_0362 = '0362'
    N_0363 = '0363'
    N_0364 = '0364'
    N_0365 = '0365'
    N_0365X = '0365x'
    N_0366 = '0366'
    N_0366X = '0366x'
    N_0367 = '0367'
    N_0369 = '0369'
    N_0371 = '0371'
    N_0372 = '0372'
    N_0372X = '0372x'
    N_0374 = '0374'
    N_0376 = '0376'
    N_0376A = '0376a'
    N_0376X = '0376x'
    N_0378 = '0378'
    N_0378X = '0378x'
    N_0380 = '0380'
    N_0384 = '0384'
    N_0386 = '0386'
    N_0388 = '0388'
    AIND_MSMA = 'aind-msma'
    AIND_DISCOVERY = 'aind-discovery'
    AIND_EPHYS = 'aind-ephys'
    AIND_OPHYS = 'aind-ophys'
    APR_OX = 'APROx'
    A_XL_OX = 'AXlOx'
    BA_RSEQ_GENETIC_TOOLS = 'BARseq_GeneticTools'
    BRAIN_STIM = 'BrainStim'
    BRAINTV_VIRAL_STRATEGIES = 'BraintvViralStrategies'
    C200 = 'C200'
    C600 = 'C600'
    C600_LATERAL = 'C600Lateral'
    C600X = 'C600x'
    CELLTYPES_TRANSGENIC_CHAR = 'CelltypesTransgenicCharacterizationGCaMP'
    CITRICACIDPILOT = 'Citricacidpilot'
    CON_9999 = 'CON-9999'
    CON_C505 = 'CON-C505'
    CON_CS04 = 'CON-CS04'
    DEEPSCOPE_SLM_DEVELOPMENT = 'DeepscopeSLMDevelopment'
    DYNAMIC_ROUTING_BEHAVIOR = 'DynamicRoutingBehaviorDev'
    DYNAMIC_ROUTING_OPTO_DEV = 'DynamicRoutingOptoDev'
    DYNAMIC_ROUTING_SURGICAL = 'DynamicRoutingSurgicalDevelopment'
    DYNAMIC_ROUTING_TASK1_PRO = 'DynamicRoutingTask1Production'
    DYNAMIC_ROUTING_TASK2_PRO = 'DynamicRoutingTask2Production'
    DYNAMIC_ROUTING_ULTRA_OPT = 'DynamicRoutingUltraOptotaggingBehavior'
    H120 = 'H120'
    H200 = 'H200'
    H301 = 'H301'
    H301T = 'H301t'
    H301_X = 'H301X'
    H501_X = 'H501X'
    H504 = 'H504'
    IS_IX = 'ISIx'
    LARGE_SCALE_VOLTAGE = 'LargeScaleVoltage'
    LEARNINGM_FISH_DEVELOPMEN = 'LearningmFISHDevelopment'
    LEARNINGM_FISH_TASK1_A = 'LearningmFISHTask1A'
    M301T = 'M301t'
    MESOSCOPE_DEVELOPMENT = 'MesoscopeDevelopment'
    M_FISH_PLATFORM_DEVELOPME = 'mFishPlatformDevelopment'
    MINDSCOPE_TRANSGENIC_CHAR = 'MindscopeTransgenicCharacterizationGCaMP'
    M_IVSCC_MET = 'mIVSCC-MET'
    M_IVSCC_ME_TX = 'mIVSCC-METx'
    M_M_PATCHX = 'mMPatchx'
    M_MPATC_HX = 'mMPATCHx'
    MOUSE_BRAIN_CELL_ATLAS_CH = 'MouseBrainCellAtlasCharacterizationPilot'
    MOUSE_BRAIN_CELL_ATLAS_CH_2 = 'MouseBrainCellAtlasCharacterizatlon'
    MOUSE_BRAIN_CELL_ATLAS_TR = 'MouseBrainCellAtlasTranssynaptic'
    MOUSE_FULL_MORPHOLOGY_FMO = 'MouseFullMorphologyFmost'
    MOUSE_GENETIC_TOOLS_PROJE = 'MouseGeneticToolsProjectionMapping'
    M_VISP_TAXL_O = 'MVisp-taxl.o'
    MULTISCOPE_SIGNAL_NOISE = 'MultiscopeSignalNoise'
    N200 = 'N200'
    N310 = 'N310'
    NEUROPIXEL_VISUAL_BEHAVIO = 'NeuropixelVisualBehavior'
    NEUROPIXEL_VISUAL_BEHAVIO_2 = 'NeuropixelVisualBehaviorDevelopment'
    NEUROPIXEL_VISUAL_CODING = 'NeuropixelVisualCoding'
    OLVSX = 'OLVSX'
    OM_FIS_HCOREGISTRATIONPIL = 'omFISHcoregistrationpilot'
    OM_FISH_CUX2_MESO = 'omFISHCux2Meso'
    OM_FISH_GAD2_MESO = 'omFISHGad2Meso'
    OM_FISH_GAD2_PILOT = 'omFISHGad2Pilot'
    OM_FISH_RBP4_MESO = 'omFISHRbp4Meso'
    OM_FISH_RORB_PILOT = 'omFISHRorbPilot'
    OM_FISHRO_BINJECTIONVIRUS = 'omFISHROBinjectionviruspilot'
    OM_FISH_SST_MESO = 'omFISHSstMeso'
    OM_FISH_VIP_MESO = 'omFISHVipMeso'
    OPEN_SCOPE_DENDRITE_COUPL = 'OpenScopeDendriteCoupling'
    OPENSCOPE_DEVELOPMENT = 'OpenscopeDevelopment'
    OPEN_SCOPE_ILLUSION = 'OpenScopeIllusion'
    OPEN_SCOPE_GLOBAL_LOCAL_O = 'OpenScopeGlobalLocalOddball'
    OPENSCOPE_GAMMA_PILOT = 'OpenscopeGammaPilot'
    OPENSCOPE_GAMMA_PRODUCTLO = 'OpenscopeGammaProductlon'
    OPENSCOPELNJECTION_PILOT = 'OpenscopelnjectionPilot'
    OPEN_SCOPE_LOOP = 'OpenScopeLoop'
    OPENSCOPE_MOTION_PLLOT = 'OpenscopeMotionPllot'
    OPENSCOPE_MOTION_PRODUCTI = 'OpenscopeMotionProduction'
    OPENSCOPE_MULTIPLEX_PILOT = 'OpenscopeMultiplexPilot'
    OPENSCOPE_MULTIPLEX_PRODU = 'OpenscopeMultiplexProduction'
    OPEN_SCOPE_PSYCODE = 'OpenScopePsycode'
    OPEN_SCOPE_SEQUENCE_LEARN = 'OpenScopeSequenceLearning'
    OPEN_SCOPE_TEMPORAL_BARCO = 'OpenScopeTemporalBarcode'
    OPEN_SCOPE_TEXTURE = 'OpenScopeTexture'
    OPEN_SCOPE_VISION2_HIPPOC = 'OpenScopeVision2Hippocampus'
    OPEN_SCOPE_VISMO = 'OpenScopeVismo'
    OPH5_X = 'OPH5X'
    SLC6_A1_NEUROPIXEL = 'SLC6A1Neuropixel'
    SMART_SPIM__GENETIC_TOOLS = 'SmartSPIM_GeneticTools'
    SURGERY_X = 'SurgeryX'
    T301 = 'T301'
    T301T = 'T301t'
    T301_X = 'T301X'
    T503 = 'T503'
    T503_X = 'T503X'
    T504 = 'T504'
    T504_X = 'T504X'
    T600 = 'T600'
    T601 = 'T601'
    T601_X = 'T601X'
    TCYTX = 'TCYTX'
    TASK_TRAINED_NETWORKS_MUL = 'TaskTrainedNetworksMultiscope'
    TASK_TRAINED_NETWORKS_NEU = 'TaskTrainedNetworksNeuropixel'
    TEMPLETON_PSYCHEDELICS = 'TempletonPsychedelics'
    TEMPLETON_TTOC = 'Templeton TTOC'
    TINY_BLUE_DOT_BEHAVIOR = 'TinyBlueDotBehavior'
    U01_BFCT = 'U01BFCT'
    VARIABILITY_AIM1 = 'VariabilityAim1'
    VARIABILITY_AIM1_PILOT = 'VariabilityAim1Pilot'
    VARIABILITY_SPONTANEOUS = 'VariabilitySpontaneous'
    VI_DEEP_DIVE_EM_VOLUME = 'VIDeepDiveEMVolume'
    VI_DEEPDLVE_DEEPSCOPE_PIE = 'VIDeepdlveDeepscopePiezo'
    VIP_AXONAL_V1_PHASE1 = 'VipAxonalV1Phase1'
    VIP_SOMATIC_V1_MESO = 'VIPSomaticV1Meso'
    VIP_SOMATIC_V1_PHASE1 = 'VipSomaticV1Phase1'
    VIP_SOMATIC_V1_PHASE2 = 'VipSomaticV1Phase2'
    VISUAL_BEHAVIOR = 'VisualBehavior'
    VISUAL_BEHAVIOR_DEVELOPME = 'VisualBehaviorDevelopment'
    VISUAL_BEHAVIOR_MULTISCOP = 'VisualBehaviorMultiscope'
    VISUAL_BEHAVIOR_MULTISCOP_2 = 'VisualBehaviorMultiscope4areasx2d'
    VISUAL_BEHAV_IOR_MULTISCO = 'VisualBehavIorMultiscopeTask1G'
    VISUAL_BEHAVIOR_TASK1_B = 'VisualBehaviorTask1B'
    S200_C = 'S200C'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023LimsProject from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr2InjectionDevice(str, Enum):
    """
    Enum class for Burr2 Injection Device.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    NANO_1 = 'Nano #1'
    IONTO_1 = 'Ionto #1'
    NANO_2 = 'Nano #2'
    IONTO_2 = 'Ionto #2'
    NANO_3 = 'Nano #3'
    IONTO_3 = 'Ionto #3'
    NANO_4 = 'Nano #4'
    IONTO_4 = 'Ionto #4'
    NANO_5 = 'Nano #5'
    IONTO_5 = 'Ionto #5'
    NANO_6 = 'Nano #6'
    IONTO_6 = 'Ionto #6'
    NANO_7 = 'Nano #7'
    IONTO_7 = 'Ionto #7'
    NANO_8 = 'Nano #8'
    IONTO_8 = 'Ionto #8'
    NANO_9 = 'Nano #9'
    IONTO_9 = 'Ionto #9'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr2InjectionDevice from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.las_rolims import LASRolims

class TestLASRolims(unittest.TestCase):
    """LASRolims unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLASRolims(self):
        """Test LASRolims"""
        # inst = LASRolims()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Procedure(str, Enum):
    """
    Enum class for Procedure
    """

    """
    allowed enum values
    """
    CUSTOM = 'Custom'
    HPC_CAM = 'HP+C CAM'
    HPC_MULTISCOPE = 'HP+C Multiscope'
    HPC_NEUROPIXEL_STYLE = 'HP+C Neuropixel style'
    HPINJ = 'HP+INJ'
    HP_INJECTION_OPTIC_FIBER = 'HP+Injection+Optic Fiber Implant'
    HP_ONLY = 'HP only'
    HP_TRANSCRANIAL_FOR_ISI = 'HP Transcranial (for ISI)'
    INJHPC = 'INJ+HP+C'
    INJWHC_NP = 'INJ+WHC NP'
    SELECT = 'Select...'
    STEREOTAXIC_INJECTION = 'Stereotaxic Injection'
    TRAINING_SURGERY = 'Training Surgery'
    WHC_NP = 'WHC NP'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Procedure from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProjectid(str, Enum):
    """
    Enum class for ProjectID.
    """

    """
    allowed enum values
    """
    N_101_03_001_10_COSTA_PG = '101-03-001-10 Costa PGA Lab Research (Direct)'
    N_102_01_007_10_CTY_M_FIS = '102-01-007-10 CTY mFISH'
    N_102_01_009_10_CTY_MORP = '102-01-009-10 CTY Morphology'
    N_102_01_011_10_CTY_CONN = '102-01-011-10 CTY Connectome EM'
    N_102_01_012_10_CTY_CONN = '102-01-012-10 CTY Connectome Meso'
    N_102_01_016_10_CTY_TAXO = '102-01-016-10 CTY Taxonomy'
    N_102_01_029_20_CTY_BRAIN = '102-01-029-20 CTY BRAIN Cell-type Specific Enhancer Viruses'
    N_102_01_031_20_W4_CTY_EU = '102-01-031-20 W4 - CTY EU Horizon 2020 BRAINTIME'
    N_102_01_031_20_W5_CTY_EU = '102-01-031-20 W5 - CTY EU Horizon 2020 BRAINTIME'
    N_102_01_032_20_CTY_MOUS = '102-01-032-20 CTY Mouse Aging'
    N_102_01_036_20_CTY_DISS = '102-01-036-20 CTY Dissemination of 3-Photon Imaging'
    N_102_01_040_20_CTY_BRAIN = '102-01-040-20 CTY BRAIN UG3/UH3 Genetic Viral Tools'
    N_102_01_043_20_CTY_OPTI = '102-01-043-20 CTY Optical interrogation'
    N_102_01_044_10_CTY_GENO = '102-01-044-10 – CTY Genomics'
    N_102_01_045_10_CTY_IVSCC = '102-01-045-10 – CTY IVSCC'
    N_102_01_046_20_CTY_WEIL = '102-01-046-20 - CTY Weill Neuronal Heterogeneity'
    N_102_01_048_10_CTY_BARC = '102-01-048-10 CTY Barcoded Connectomics'
    N_102_01_049_20_CTY_OPIO = '102-01-049-20 - CTY Opioid Transcriptomics'
    N_102_01_054_20_CTY_PFAC = '102-01-054-20 CTY PFAC'
    N_102_01_055_20_CTY_EM_M = '102-01-055-20 CTY EM Motor Cortex'
    N_102_01_059_20_CTY_SCORC = '102-01-059-20 CTY SCORCH'
    N_102_01_060_20_CTY_BRAI = '102-01-060-20 CTY Brain Drain'
    N_102_01_061_20_CTY_BICAN = '102-01-061-20 CTY BICAN Human and NHP Atlas'
    N_102_01_062_10_AIBS_BICA = '102-01-062-10 AIBS BICAN Mouse Developmental Atlas'
    N_102_01_064_10_CTY_GENE = '102-01-064-10 CTY Genetic Tools'
    N_102_01_066_20_AIBS_CTY = '102-01-066-20 AIBS CTY CONNECTS HIVE'
    N_102_01_066_20_AIND_CTY = '102-01-066-20 AIND CTY CONNECTS HIVE'
    N_102_01_068_20_CTY_CONNE = '102-01-068-20 CTY CONNECTS Patchlink'
    N_102_01_069_20_PRE_SPE = '102-01-069-20 Pre-Spend'
    N_102_01_070_20_CTY_CONNE = '102-01-070-20 CTY CONNECTS MouseConnects'
    N_102_01_073_20_CTY_CT_P = '102-01-073-20 CTY CT Projectome'
    N_102_01_078_20_AIBS_VOC = '102-01-078-20 AIBS Vocal Circuit'
    N_102_01_079_20_AIBS_CONN = '102-01-079-20 AIBS CONNECTS TransNeuronal Tools'
    N_102_01_083_20_AIBS_WB_A = '102-01-083-20 AIBS WB AAV Toolbox'
    N_102_01_999_10_CTY_PROG = '102-01-999-10 CTY Program Admin'
    N_102_02_004_10_BTV_VISU = '102-02-004-10 BTV Visual Behavior'
    N_102_02_012_20_BTV_BRAIN = '102-02-012-20 BTV BRAIN Viral Strategies'
    N_102_04_004_10_OTH_MERI = '102-04-004-10 OTH Meritorious Scholar Directed Research'
    N_102_04_006_20_OTH_MEAS = '102-04-006-20 OTH Measuring Consciousness Ph2 (TBD)'
    N_102_04_007_10_APLD_TAR = '102-04-007-10 APLD Targeted CNS Gene Therapy'
    N_102_04_011_10_CTY_SR_SY = '102-04-011-10 CTY SR: SYNGAP1'
    N_102_04_012_10_CTY_SR_F = '102-04-012-10 : CTY SR: Friedreich Ataxia'
    N_102_04_016_20_CTY_DRAV = '102-04-016-20 CTY Dravet Phase 3 WRF'
    N_102_04_017_10_AIBS_EPI = '102-04-017-10 AIBS Epilepsy'
    N_102_04_019_20_AIBS_DSF = '102-04-019-20 AIBS DSF Dravet'
    N_102_88_001_10_XPG_CORE = '102-88-001-10 XPG Core Imaging: BARseq'
    N_102_88_001_10_XPG_CORE_2 = '102-88-001-10 XPG Core Imaging: Methods Development'
    N_122_88_002_10_XPG_CORE = '122-88-002-10 XPG Core NSB Behavior'
    N_102_88_003_10_ANIMAL = '102-88-003-10 Animal Care Team'
    N_102_88_005_10_TRANSGEN = '102-88-005-10 Transgenic Colony Management'
    N_102_88_008_10_LAB_ANI = '102-88-008-10 Lab Animal Services'
    N_106_09_001_10_TISSUE = '106-09-001-10 Tissue Immunity'
    N_110_01_001_10_PG_PROTE = '110-01-001-10 PG Proteomics'
    N_121_01_016_20_MSP_BRAIN = '121-01-016-20 MSP BRAIN OpenScope'
    N_121_01_018_20_MSP_EPHA = '121-01-018-20 MSP Ephaptic Cell Typ'
    N_121_01_023_20_MSP_TEMP = '121-01-023-20 MSP Templeton - Testing Theories of Consciousness'
    N_121_01_025_20_MSP_U01 = '121-01-025-20 MSP U01 Bridging Function, Connectivity, & Transcriptomics'
    N_121_01_026_20_MSP_TEMP = '121-01-026-20 MSP Templeton Measuring Distinct Conscious State'
    N_122_01_001_10_AIND_SCI = '122-01-001-10 AIND Scientific Activities'
    N_122_01_002_20_MOLECULA = '122-01-002-20 Molecular Core'
    N_122_01_004_20_AIND_BRA = '122-01-004-20 AIND Brainstem RF1'
    N_122_01_010_20_AIND_POO = '122-01-010-20 - AIND Poo Simons BTI'
    N_122_01_011_20_AIND_COH = '122-01-011-20 - AIND Cohen JHU R01 Transferred Subaward'
    N_122_01_012_20_AIND_RF1 = '122-01-012-20 - AIND RF1 Functions of locus coeruleus'
    N_122_01_013_10_MSP_SCIE = '122-01-013-10 MSP Scientific Activities'
    N_122_01_014_20_AIND_SIE = '122-01-014-20 - AIND Siegle U01 NPOpto'
    N_122_01_019_20_AIND_CZI = '122-01-019-20 AIND CZI Collaborative Pairs'
    N_122_01_020_20_AIBS_COH = '122-01-020-20 AIBS Cohen BICAN R01'
    N_122_01_020_20_AIND_COH = '122-01-020-20 AIND Cohen BICAN R01'
    N_122_01_022_20_AIND_POD = '122-01-022-20 AIND Podgorski UM1'
    N_123_01_003_20_MOTOR_C = '123-01-003-20 Motor Circuit Dysfunction in PD'
    N_124_01_001_10_BRAIN_C = '124-01-001-10 Brain & Consciousness (Direct)'
    N_125_01_001_10_SEA_HUB = '125-01-001-10 - SeaHub Scientific Activities (Direct)'
    N_127_01_001_10_CELL_CI = '127-01-001-10 Cell & Circuit Therapeutics'
    AAV_PRODUCTION_102_88_004 = 'AAV production 102-88-004-10'
    R_D_102_88_004_10 = 'R&D 102-88-004-10'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProjectid from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023AindProjectName(str, Enum):
    """
    Enum class for AIND Project Name.
    """

    """
    allowed enum values
    """
    BRAIN__WIDE__CIRCUIT__DYN = 'Brain Wide Circuit Dynamics'
    CELL__TYPE__LOOKUP__TABLE = 'Cell Type Lookup Table'
    COGNITIVE_FLEXIBILITY_IN = 'Cognitive flexibility in patch foraging'
    CREDIT_ASSIGNMENT_DURING = 'Credit assignment during learning (Brain Computer Interface)'
    DYNAMIC__ROUTING = 'Dynamic Routing'
    FORCE__FORGING = 'Force Forging'
    GENETIC__PERTURBATION__PR = 'Genetic Perturbation Project (GPP)'
    INDICATOR__TESTING = 'Indicator Testing'
    INFORMATION_SEEKING_IN_PA = 'Information seeking in partially observable environments'
    MEDULLA = 'Medulla'
    MULTIPLEXED_NM = 'Multiplexed NM'
    NEUROMODULATOR_CIRCUIT_DY = 'Neuromodulator circuit dynamics during foraging'
    OPEN_SCOPE = 'OpenScope'
    OPHYS_M_FISH__CELL_TYPES = 'Ophys mFISH* \"Cell types and learning\"'
    PLACE = 'PLACE'
    SINGLE__NEURON__COMPUTATI = 'Single-Neuron Computations within Brain-Wide Circuits (SCBC)*'
    THALAMUS = 'Thalamus'
    THALAMUS_AIND__SCIENTIFIC = 'Thalamus - AIND Scientific Activites'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023AindProjectName from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019IacucProtocol(str, Enum):
    """
    Enum class for IacucProtocol
    """

    """
    allowed enum values
    """
    N_2001 = '2001'
    N_2002 = '2002'
    N_2003 = '2003'
    N_2004 = '2004'
    N_2005 = '2005'
    N_2006 = '2006'
    N_2011 = '2011'
    N_2102 = '2102'
    N_2103 = '2103'
    N_2104 = '2104'
    N_2105 = '2105'
    N_2106 = '2106'
    N_2107 = '2107'
    N_2108 = '2108'
    N_2109 = '2109'
    N_2110 = '2110'
    N_2113 = '2113'
    N_2115 = '2115'
    N_2117 = '2117'
    N_2201 = '2201'
    N_2202 = '2202'
    N_2205 = '2205'
    N_2212 = '2212'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019IacucProtocol from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASLimsworkflow(str, Enum):
    """
    Enum class for LIMSWorkflow.
    """

    """
    allowed enum values
    """
    N_2P_SERIAL_IMAGING = '2p serial Imaging'
    T601_1_RETINA = 'T601.1 Retina'
    T601_2A_RETROGRADE_CAV2 = 'T601.2a Retrograde CAV2-Cre;Ai75'
    T601_2B_RETROGRADE_RABI = 'T601.2b Retrograde Rabies-GFP'
    T601_2C_RETROGRADE_FLUO = 'T601.2c Retrograde Fluorogold'
    T601_3A_ANTEROGRADE_CRE = 'T601.3a Anterograde Cre-Defined EGFP'
    T601_3B_ANTEROGRADE_CRE = 'T601.3b Anterograde Cre-Deflned SypEGFP'
    T601_4_ANTEROGRADE_TARG = 'T601.4 Anterograde Target Defined'
    T601_5_TRANS_SYNAPTIC = 'T601.5 trans-synaptic'
    SCREENING = 'Screening'
    CHARACTERIZATION = 'Characterization'
    T503_2_ANTEROGRADE_TARG = 'T503.2 Anterograde Target-Defined'
    T503_3_ALZHEIMER_S_PLAQ = 'T503.3 Alzheimer\'s Plaque'
    T503_3_CONTROL = 'T503.3 control'
    T503_ANTEROGRADE_CRE_DEF = 'T503 anterograde Cre-defined SypEGFP'
    MGT_ANTEROGRADE_PROJECT = 'MGT Anterograde Projection Mapping'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASLimsworkflow from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023LimsTaskflow(str, Enum):
    """
    Enum class for LIMSTaskflow.
    """

    """
    allowed enum values
    """
    AIND_EPHYS_SURGERY_ONLY = 'AIND Ephys (Surgery only)'
    AIND_EPHYS_PASSIVE_BEHAVIOR = 'AIND Ephys (Passive Behavior)'
    AIND_U19_AAV_RETROGRADE = 'AIND U19 AAV Retrograde'
    AIND_U19_RAB_V_RETROGRADE = 'AIND U19 RabV Retrograde'
    AIND_U19_THALAMUS = 'AIND U19 Thalamus'
    AIND_WATERLOG = 'AIND Waterlog'
    BRAIN_LARGE_SCALE_RECORDING = 'BRAIN Large Scale Recording'
    BRAIN_MOUSE_BRAIN_CELL_ATLAS_TRANS_SYNAPTIC = 'BRAIN Mouse Brain Cell Atlas trans-synaptic'
    BRAIN_OBSERVATORY_DEEPSCOPE = 'Brain Observatory Deepscope'
    BRAIN_OBSERVATORY_EPHYS_DEV = 'Brain Observatory Ephys Dev'
    BRAIN_OBSERVATORY_MAPSCOPE = 'Brain Observatory Mapscope'
    BRAIN_OBSERVATORY_MESOSCOPE = 'Brain Observatory Mesoscope'
    BRAIN_OBSERVATORY_MESOSCOPE_1G = 'Brain Observatory Mesoscope 1G'
    BRAIN_OBSERVATORY_NEUROPIXEL_DEV = 'Brain Observatory Neuropixel Dev'
    BRAIN_OBSERVATORY_TRANSGENIC_CHARACTERIZATION = 'Brain Observatory Transgenic Characterization'
    BRAIN_OBSERVATORY_V1_DD = 'Brain Observatory V1DD'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR = 'Brain Observatory Visual Behavior'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR_1B = 'Brain Observatory Visual Behavior 1B'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR_NEUROPIXEL = 'Brain Observatory Visual Behavior Neuropixel'
    BRAIN_OBSERVATORY_VISUAL_CODING = 'Brain Observatory Visual Coding'
    BTV_BRAIN_VIRAL_STRATEGIES = 'BTV BRAIN Viral Strategies'
    CITRIC_ACID_PILOT = 'Citric Acid Pilot'
    EPHYS_DEV_VISUAL_BEHAVIOR = 'Ephys Dev Visual Behavior'
    EPHYS_DEV_VISUAL_BEHAVIOR_2 = 'Ephys Dev Visual Behavior 2'
    EPHYS_TASK_DEV_DYNAMIC_ROUTING_DOC_LEFT_EYE = 'Ephys Task Dev Dynamic Routing DOC Left Eye'
    EPHYS_TASK_DEV_DYANMIC_ROUTING_NSB_BEH = 'Ephys Task Dev Dyanmic Routing (NSB Beh)'
    EPHYS_TASK_DEV_DYNAMIC_ROUTING_SC_BEH = 'Ephys Task Dev Dynamic Routing (S/C Beh)'
    IVSCC_HVA_RETRO_PATCHSEQ = 'IVSCC HVA Retro PatchSeq'
    IVSCCM_INJECTION = 'IVSCCm injection'
    IVSPCM_INJECTION = 'IVSPCm Injection'
    MGT_LAB = 'MGT Lab'
    MGT_TISSUECYTE = 'MGT TissueCyte'
    MINDSCOPE_2P_TESTING = 'Mindscope 2P Testing'
    MSP_DYNAMIC_ROUTING_BEHAVIOR_DEVELOPMENT = 'MSP Dynamic Routing Behavior Development'
    MSP_DYNAMIC_ROUTING_OPTO_DEV = 'MSP Dynamic Routing Opto Dev'
    MSP_DYNAMIC_ROUTING_SURGICAL_DEVELOPMENT = 'MSP Dynamic Routing Surgical Development'
    MSP_DYNAMIC_ROUTING_ULTRA_OPTOTAGGING_BEHAVIOR = 'MSP Dynamic Routing Ultra Optotagging Behavior'
    MSP_DYNAMIC_ROUTING_TASK_1_PRODUCTION = 'MSP Dynamic Routing Task 1 Production'
    MSP_DYNAMIC_ROUTING_TASK_2_PRODUCTION = 'MSP Dynamic Routing Task 2 Production'
    MSP_GCAMP8_TESTING = 'MSP GCaMP8 Testing'
    MSP_GCAMP8_TESTING_RO = 'MSP GCaMP8 Testing (RO)'
    MSP_LEARNING_MFISH_DEVELOPMENT = 'MSP Learning & mFISH Development'
    MSP_LEARNING_MFISH_DEVELOPMENT_DOX = 'MSP Learning & mFISH Development (Dox)'
    MSP_LEARNING_MFISH_FRONTAL_WINDOW_DEV = 'MSP Learning & mFISH Frontal Window Dev'
    MSP_LEARNING_MFISH_VIRUS_TESTING = 'MSP Learning & mFISH Virus Testing'
    MSP_OMFISH_COREGISTRATION_PILOT = 'MSP omFISH Co-registration Pilot'
    MSP_OMFISH_CUX2_PILOT = 'MSP omFISH Cux2 Pilot'
    MSP_OMFISH_GAD2_MESO = 'MSP omFISH Gad2 Meso'
    MSP_OMFISH_GAD2_PILOT = 'MSP omFISH Gad2 Pilot'
    MSP_OMFISH_RBP4_MESO = 'MSP omFISH Rbp4 Meso'
    MSP_OMFISH_RORB_PILOT = 'MSP omFISH Rorb Pilot'
    MSP_OMFISH_ROB_INJECTION_VIRUS_PILOT = 'MSP omFISH ROB Injection Virus Pilot'
    MSP_OMFISH_SST_MESO_GAMMASTIM = 'MSP omFISH Sst Meso (GammaStim)'
    MSP_OMFISH_VIP_MESO_GAMMASTIM = 'MSP omFISH Vip Meso (GammaStim)'
    MSP_OPENSCOPE_DENDRITE_COUPLING = 'MSP OpenScope Dendrite Coupling'
    MSP_OPENSCOPE_ILLUSION = 'MSP OpenScope Illusion'
    MSP_OPENSCOPE_GLOBAL_LOCAL_ODDBALLS_COHORT_1 = 'MSP OpenScope Global Local Oddballs (Cohort 1)'
    MSP_OPENSCOPE_GLOBAL_LOCAL_ODDBALLS_COHORT_2 = 'MSP OpenScope Global Local Oddballs (Cohort 2)'
    MSP_TASK_TRAINED_NETWORKS_MULTISCOPE = 'MSP Task Trained Networks Multiscope'
    MSP_TASK_TRAINED_NETWORKS_NEUROPIXEL = 'MSP Task Trained Networks Neuropixel'
    MSP_U01_BRIDGING_FUNCTION_CONNECTIVITY_TRANSCRIPTOMICS = 'MSP U01 Bridging Function, Connectivity, and Transcriptomics'
    MSP_VARIABILITY_AIM_1 = 'MSP Variability Aim 1'
    MSP_VARIABILITY_AIM_1_PILOT = 'MSP Variability Aim 1 Pilot'
    MSP_VARIABILITY_SPONTANEOUS = 'MSP Variability Spontaneous'
    MSP_VIP_AXONAL_V1 = 'MSP VIP Axonal V1'
    MSP_VIP_SOMATIC_V1 = 'MSP VIP Somatic V1'
    OPENSCOPE_GAMMA_PILOT = 'OpenScope Gamma Pilot'
    OPENSCOPE_GAMMA_PRODUCTION = 'OpenScope Gamma Production'
    OPENSCOPE_INJECTION_VOLUME_PILOT = 'OpenScope Injection Volume Pilot'
    OPENSCOPE_MOTION_PILOT = 'OpenScope Motion Pilot'
    OPENSCOPE_MULTIPLEX_PILOT_INJECTION = 'OpenScope Multiplex Pilot Inj'
    OPENSCOPE_MULTIPLEX_PILOT_NOINJECTION = 'OpenScope Multiplex Pilot Nolnj'
    OPENSCOPE_MULTIPLEX_PRODUCTION_NOINJECTION = 'OpenScope Multiplex Production NoInj'
    OPENSCOPE_MULTIPLEX_PRODUCTION = 'OpenScope Multiplex Production'
    OPENSCOPE_LOOP = 'OpenScope Loop'
    OPENSCOPE_MOTION_PRODUCTION = 'Openscope Motion Production'
    OPENSCOPE_PSYCODE = 'OpenScope Psycode'
    OPENSCOPE_SEQUENCE_LEARNING = 'OpenScope Sequence Learning'
    OPENSCOPE_TEMPORAL_BARCODE = 'OpenScope Temporal Barcode'
    OPENSCOPE_TEMPORAL_BARCODE_TESTING = 'OpenScope Temporal Barcode Testing'
    OPENSCOPE_TEXTURE_ACTIVE = 'OpenScope Texture (Active)'
    OPENSCOPE_TEXTURE_PASSIVE = 'OpenScope Texture (Passive)'
    OPENSCOPE_VIRUS_VALIDATION = 'Openscope Virus Validation'
    OPENSCOPE_VISION_2_HIPPOCAMPUS = 'OpenScope Vision 2 Hippocampus'
    OPENSCOPE_VISMO = 'OpenScope Vismo'
    OPENSCOPE_WHC_2P_DEV = 'OpenScope WHC 2P Dev'
    TEMPLETON_PSYCHEDELICS = 'Templeton Psychedelics'
    TILTY_MOUSE = 'Tilty Mouse'
    TINY_BLUE_DOT_BEHAVIOR = 'Tiny Blue Dot Behavior'
    TRANSGENIC_CHARACTERIZATION_PASSIVE = 'Transgenic Characterization (Passive)'
    VISB_DEV_CONTROL_GROUP = 'VisB Dev Control Group'
    VISB_LATERAL_PREP_DEVELOPMENT = 'VisB Lateral Prep Development'
    VISB_TASK_2_DEVELOPMENT = 'VisB Task 2 Development'
    VGT_ENHANCERS_TRANSSYNAPTIC = 'VGT Enhancers Transsynaptic'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023LimsTaskflow from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from aind_sharepoint_service_async_client.models.nsb2019_after1_st_injection import NSB2019After1StInjection
from aind_sharepoint_service_async_client.models.nsb2019_after2_nd_injection import NSB2019After2NdInjection
from aind_sharepoint_service_async_client.models.nsb2019_contusion import NSB2019Contusion
from aind_sharepoint_service_async_client.models.nsb2019_craniotomy_type import NSB2019CraniotomyType
from aind_sharepoint_service_async_client.models.nsb2019_during1_st_injection import NSB2019During1StInjection
from aind_sharepoint_service_async_client.models.nsb2019_during2_nd_injection import NSB2019During2NdInjection
from aind_sharepoint_service_async_client.models.nsb2019_durotomy import NSB2019Durotomy
from aind_sharepoint_service_async_client.models.nsb2019_edema_swelling import NSB2019EdemaSwelling
from aind_sharepoint_service_async_client.models.nsb2019_exudate_severity import NSB2019ExudateSeverity
from aind_sharepoint_service_async_client.models.nsb2019_eye_affected import NSB2019EyeAffected
from aind_sharepoint_service_async_client.models.nsb2019_eye_issue import NSB2019EyeIssue
from aind_sharepoint_service_async_client.models.nsb2019_first_round_inj_iso_level import NSB2019FirstRoundInjIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_first_round_inj_workstation import NSB2019FirstRoundInjWorkstation
from aind_sharepoint_service_async_client.models.nsb2019_firstroundiontoissue import NSB2019Firstroundiontoissue
from aind_sharepoint_service_async_client.models.nsb2019_firstroundiontonumber import NSB2019Firstroundiontonumber
from aind_sharepoint_service_async_client.models.nsb2019_firstroundnanojectnumber import NSB2019Firstroundnanojectnumber
from aind_sharepoint_service_async_client.models.nsb2019_headpost_type import NSB2019HeadpostType
from aind_sharepoint_service_async_client.models.nsb2019_hematoma import NSB2019Hematoma
from aind_sharepoint_service_async_client.models.nsb2019_hp_durotomy import NSB2019HpDurotomy
from aind_sharepoint_service_async_client.models.nsb2019_hp_iso_level import NSB2019HpIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_hp_location import NSB2019HpLocation
from aind_sharepoint_service_async_client.models.nsb2019_hp_perferations import NSB2019HpPerferations
from aind_sharepoint_service_async_client.models.nsb2019_hp_work_station import NSB2019HpWorkStation
from aind_sharepoint_service_async_client.models.nsb2019_iacuc_protocol import NSB2019IacucProtocol
from aind_sharepoint_service_async_client.models.nsb2019_implant_id_coverslip_type import NSB2019ImplantIdCoverslipType
from aind_sharepoint_service_async_client.models.nsb2019_inj1_angle import NSB2019Inj1Angle
from aind_sharepoint_service_async_client.models.nsb2019_inj1_hemisphere import NSB2019Inj1Hemisphere
from aind_sharepoint_service_async_client.models.nsb2019_inj1_retsetting import NSB2019Inj1Retsetting
from aind_sharepoint_service_async_client.models.nsb2019_inj1_round import NSB2019Inj1Round
from aind_sharepoint_service_async_client.models.nsb2019_inj1_type import NSB2019Inj1Type
from aind_sharepoint_service_async_client.models.nsb2019_inj2_angle import NSB2019Inj2Angle
from aind_sharepoint_service_async_client.models.nsb2019_inj2_hemisphere import NSB2019Inj2Hemisphere
from aind_sharepoint_service_async_client.models.nsb2019_inj2_retsetting import NSB2019Inj2Retsetting
from aind_sharepoint_service_async_client.models.nsb2019_inj2_round import NSB2019Inj2Round
from aind_sharepoint_service_async_client.models.nsb2019_inj2_type import NSB2019Inj2Type
from aind_sharepoint_service_async_client.models.nsb2019_iontonumberhpinj import NSB2019Iontonumberhpinj
from aind_sharepoint_service_async_client.models.nsb2019_issue import NSB2019Issue
from aind_sharepoint_service_async_client.models.nsb2019_laceration import NSB2019Laceration
from aind_sharepoint_service_async_client.models.nsb2019_light_cycle import NSB2019LightCycle
from aind_sharepoint_service_async_client.models.nsb2019_lims_project_code import NSB2019LimsProjectCode
from aind_sharepoint_service_async_client.models.nsb2019_lims_required import NSB2019LimsRequired
from aind_sharepoint_service_async_client.models.nsb2019_limstaskflow import NSB2019Limstaskflow
from aind_sharepoint_service_async_client.models.nsb2019_previously_injected import NSB2019PreviouslyInjected
from aind_sharepoint_service_async_client.models.nsb2019_procedure import NSB2019Procedure
from aind_sharepoint_service_async_client.models.nsb2019_project_id import NSB2019ProjectId
from aind_sharepoint_service_async_client.models.nsb2019_scabbing import NSB2019Scabbing
from aind_sharepoint_service_async_client.models.nsb2019_second_round_inj_iso_level import NSB2019SecondRoundInjIsoLevel
from aind_sharepoint_service_async_client.models.nsb2019_second_round_ionto_issue import NSB2019SecondRoundIontoIssue
from aind_sharepoint_service_async_client.models.nsb2019_second_round_workstation import NSB2019SecondRoundWorkstation
from aind_sharepoint_service_async_client.models.nsb2019_secondroundiontonumber import NSB2019Secondroundiontonumber
from aind_sharepoint_service_async_client.models.nsb2019_secondroundnanojectnumber import NSB2019Secondroundnanojectnumber
from aind_sharepoint_service_async_client.models.nsb2019_sex import NSB2019Sex
from aind_sharepoint_service_async_client.models.nsb2019_sinus_bleed import NSB2019SinusBleed
from aind_sharepoint_service_async_client.models.nsb2019_surgery_status import NSB2019SurgeryStatus
from aind_sharepoint_service_async_client.models.nsb2019_touch_up_status import NSB2019TouchUpStatus
from aind_sharepoint_service_async_client.models.nsb2019_window_clarity import NSB2019WindowClarity
from typing import Optional, Set
from typing_extensions import Self

class NSB2019List(BaseModel):
    """
    Fields in Sharepoint list
    """ # noqa: E501
    age_x0020_at_x0020_injection: Optional[StrictStr] = Field(default=None, alias="Age_x0020_at_x0020_Injection")
    ap2nd_inj: Optional[StrictStr] = Field(default=None, alias="AP2ndInj")
    author_id: Optional[StrictInt] = Field(default=None, alias="AuthorId")
    breg2_lamb: Optional[StrictStr] = Field(default=None, alias="Breg2Lamb")
    cage: Optional[StrictStr] = Field(default=None, alias="Cage")
    color_tag: Optional[StrictStr] = Field(default=None, alias="_ColorTag")
    com_after1st_inj: Optional[NSB2019After1StInjection] = Field(default=None, alias="ComAfter1stInj")
    com_after2nd_inj: Optional[NSB2019After2NdInjection] = Field(default=None, alias="ComAfter2ndInj")
    com_coplanar: Optional[NSB2019Laceration] = Field(default=None, alias="ComCoplanar")
    com_damage: Optional[NSB2019Hematoma] = Field(default=None, alias="ComDamage")
    com_during1st_inj: Optional[NSB2019During1StInjection] = Field(default=None, alias="ComDuring1stInj")
    com_during2nd_inj: Optional[NSB2019During2NdInjection] = Field(default=None, alias="ComDuring2ndInj")
    com_durotomy: Optional[NSB2019Durotomy] = Field(default=None, alias="ComDurotomy")
    com_sinusbleed: Optional[NSB2019SinusBleed] = Field(default=None, alias="ComSinusbleed")
    com_swelling: Optional[NSB2019EdemaSwelling] = Field(default=None, alias="ComSwelling")
    com_window: Optional[NSB2019WindowClarity] = Field(default=None, alias="ComWindow")
    compliance_asset_id: Optional[StrictStr] = Field(default=None, alias="ComplianceAssetId")
    contusion: Optional[NSB2019Contusion] = Field(default=None, alias="Contusion")
    craniotomy_type: Optional[NSB2019CraniotomyType] = Field(default=None, alias="CraniotomyType")
    created: Optional[datetime] = Field(default=None, alias="Created")
    date1st_injection: Optional[datetime] = Field(default=None, alias="Date1stInjection")
    date2nd_injection: Optional[datetime] = Field(default=None, alias="Date2ndInjection")
    date_x0020_of_x0020_birth: Optional[datetime] = Field(default=None, alias="Date_x0020_of_x0020_Birth")
    date_x0020_of_x0020_surgery: Optional[datetime] = Field(default=None, alias="Date_x0020_of_x0020_Surgery")
    date_range_end: Optional[datetime] = Field(default=None, alias="DateRangeEnd")
    date_range_start: Optional[datetime] = Field(default=None, alias="DateRangeStart")
    dv2nd_inj: Optional[StrictStr] = Field(default=None, alias="DV2ndInj")
    editor_id: Optional[StrictInt] = Field(default=None, alias="EditorId")
    end_x0020_of_x0020_week: Optional[datetime] = Field(default=None, alias="End_x0020_of_x0020_Week")
    exudate_x0020_severity: Optional[NSB2019ExudateSeverity] = Field(default=None, alias="Exudate_x0020_Severity")
    eye_x0020_affected: Optional[NSB2019EyeAffected] = Field(default=None, alias="Eye_x0020_Affected")
    eye_x0020_issue: Optional[NSB2019EyeIssue] = Field(default=None, alias="Eye_x0020_Issue")
    fiber_implant1: Optional[StrictBool] = Field(default=None, alias="FiberImplant1")
    fiber_implant1_dv: Optional[StrictStr] = Field(default=None, alias="FiberImplant1DV")
    fiber_implant2: Optional[StrictBool] = Field(default=None, alias="FiberImplant2")
    fiber_implant2_dv: Optional[StrictStr] = Field(default=None, alias="FiberImplant2DV")
    field30: Optional[StrictStr] = None
    field50: Optional[StrictStr] = None
    first_inj_recovery: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FirstInjRecovery")
    first_injection_iso_duration: Optional[StrictStr] = Field(default=None, alias="FirstInjectionIsoDuration")
    first_injection_weight_after: Optional[StrictStr] = Field(default=None, alias="FirstInjectionWeightAfter")
    first_injection_weight_befor: Optional[StrictStr] = Field(default=None, alias="FirstInjectionWeightBefor")
    first_round_ionto_issue: Optional[NSB2019Firstroundiontoissue] = Field(default=None, alias="FirstRoundIontoIssue")
    headpost_type: Optional[NSB2019HeadpostType] = Field(default=None, alias="HeadpostType")
    hemisphere2nd_inj: Optional[NSB2019Inj2Hemisphere] = Field(default=None, alias="Hemisphere2ndInj")
    hp_x0020_a_x002f_p: Optional[StrictStr] = Field(default=None, alias="HP_x0020_A_x002f_P")
    hp_x0020_diameter: Optional[StrictStr] = Field(default=None, alias="HP_x0020_Diameter")
    hp_durotomy: Optional[NSB2019HpDurotomy] = Field(default=None, alias="HPDurotomy")
    hp_x0020__x0026__x0020_inj: Optional[StrictStr] = Field(default=None, alias="HP_x0020__x0026__x0020_Inj")
    hp_iso_level: Optional[NSB2019HpIsoLevel] = Field(default=None, alias="HPIsoLevel")
    hp_loc: Optional[NSB2019HpLocation] = Field(default=None, alias="HpLoc")
    hp_x0020_m_x002f_l: Optional[StrictStr] = Field(default=None, alias="HP_x0020_M_x002f_L")
    hp_perf: Optional[NSB2019HpPerferations] = Field(default=None, alias="HpPerf")
    hp_prev_inject: Optional[NSB2019PreviouslyInjected] = Field(default=None, alias="HpPrevInject")
    hp_recovery: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="HPRecovery")
    x0031_hp_x0020_requestor_x0020_: Optional[StrictStr] = Field(default=None, alias="_x0031_HP_x0020_Requestor_x0020_")
    hp_requestor_comments_plaintext: Optional[StrictStr] = Field(default=None, alias="HPRequestorCommentsPlaintext")
    hp_surgeon_comments: Optional[StrictStr] = Field(default=None, alias="HPSurgeonComments")
    hp_work_station: Optional[NSB2019HpWorkStation] = Field(default=None, alias="HpWorkStation")
    iacuc_x0020_protocol_x0020__x002: Optional[NSB2019IacucProtocol] = Field(default=None, description="Create a secondary List for Protocols and link to drugs", alias="IACUC_x0020_Protocol_x0020__x002")
    id: Optional[StrictInt] = Field(default=None, alias="ID")
    implant_id_coverslip_type: Optional[NSB2019ImplantIdCoverslipType] = Field(default=None, alias="ImplantIDCoverslipType")
    inj1_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj1AlternatingTime")
    inj1_angle_v2: Optional[StrictStr] = Field(default=None, alias="Inj1Angle_v2")
    inj1_current: Optional[StrictStr] = Field(default=None, alias="Inj1Current")
    inj1_lenghtof_time: Optional[StrictStr] = Field(default=None, alias="Inj1LenghtofTime")
    inj1_round: Optional[NSB2019Inj1Round] = Field(default=None, alias="Inj1Round")
    inj1_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj1StorageLocation")
    inj1_type: Optional[NSB2019Inj1Type] = Field(default=None, alias="Inj1Type")
    inj1_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj1VirusStrain_rt")
    inj1_vol: Optional[StrictStr] = Field(default=None, alias="Inj1Vol")
    inj1angle0: Optional[NSB2019Inj1Angle] = Field(default=None, alias="Inj1angle0")
    inj1volperdepth: Optional[StrictStr] = None
    inj2_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj2AlternatingTime")
    inj2_angle_v2: Optional[StrictStr] = Field(default=None, alias="Inj2Angle_v2")
    inj2_current: Optional[StrictStr] = Field(default=None, alias="Inj2Current")
    inj2_lenghtof_time: Optional[StrictStr] = Field(default=None, alias="Inj2LenghtofTime")
    inj2_round: Optional[NSB2019Inj2Round] = Field(default=None, alias="Inj2Round")
    inj2_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj2StorageLocation")
    inj2_type: Optional[NSB2019Inj2Type] = Field(default=None, alias="Inj2Type")
    inj2_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj2VirusStrain_rt")
    inj2_vol: Optional[StrictStr] = Field(default=None, alias="Inj2Vol")
    inj2angle0: Optional[NSB2019Inj2Angle] = Field(default=None, alias="Inj2angle0")
    inj2volperdepth: Optional[StrictStr] = None
    ionto_number_hpinj: Optional[NSB2019Iontonumberhpinj] = Field(default=None, alias="IontoNumberHPINJ")
    ionto_number_inj1: Optional[NSB2019Firstroundiontonumber] = Field(default=None, alias="IontoNumberInj1")
    ionto_number_inj2: Optional[NSB2019Secondroundiontonumber] = Field(default=None, alias="IontoNumberInj2")
    iso_x0020_on: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Iso_x0020_On")
    issue: Optional[NSB2019Issue] = Field(default=None, alias="Issue")
    lab_tracks_x0020_group: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_Group")
    lab_tracks_x0020_id: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_ID")
    lab_tracks_x0020_requestor: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_Requestor")
    lims_x0020_required: Optional[NSB2019LimsRequired] = Field(default=None, description="Is LIMs Entry required", alias="LIMs_x0020_Required")
    light_x0020_cycle: Optional[NSB2019LightCycle] = Field(default=None, alias="Light_x0020_Cycle")
    lim_staskflow1: Optional[NSB2019Limstaskflow] = Field(default=None, alias="LIMStaskflow1")
    lims_x0020_link: Optional[StrictStr] = Field(default=None, alias="LIMS_x0020_link")
    lims_x0020_project_x0020_code: Optional[NSB2019LimsProjectCode] = Field(default=None, alias="Lims_x0020_Project_x0020_Code")
    long1st_round_inj_cmts: Optional[StrictStr] = Field(default=None, alias="Long1stRoundInjCmts")
    long2nd_rnd_inj_cmts: Optional[StrictStr] = Field(default=None, alias="Long2ndRndInjCmts")
    long_requestor_comments: Optional[StrictStr] = Field(default=None, alias="LongRequestorComments")
    long_surgeon_comments: Optional[StrictStr] = Field(default=None, alias="LongSurgeonComments")
    ml2nd_inj: Optional[StrictStr] = Field(default=None, alias="ML2ndInj")
    modified: Optional[datetime] = Field(default=None, alias="Modified")
    nanoject_number_inj10: Optional[NSB2019Firstroundnanojectnumber] = Field(default=None, alias="NanojectNumberInj10")
    nanoject_number_inj2: Optional[NSB2019Secondroundnanojectnumber] = Field(default=None, alias="NanojectNumberInj2")
    nd_roung_injection_comments: Optional[StrictStr] = Field(default=None, alias="ndRoungInjectionComments")
    pedigree_name: Optional[StrictStr] = Field(default=None, alias="PedigreeName")
    procedure: Optional[NSB2019Procedure] = Field(default=None, description="Type of Surgical Procedure", alias="Procedure")
    project_x0020_id_x0020__x0028_te: Optional[NSB2019ProjectId] = Field(default=None, alias="Project_x0020_ID_x0020__x0028_te")
    ret_setting0: Optional[NSB2019Inj1Retsetting] = Field(default=None, alias="retSetting0")
    ret_setting1: Optional[NSB2019Inj2Retsetting] = Field(default=None, alias="retSetting1")
    round1_inj_isolevel: Optional[NSB2019FirstRoundInjIsoLevel] = Field(default=None, alias="Round1InjIsolevel")
    round2_inj_isolevel: Optional[NSB2019SecondRoundInjIsoLevel] = Field(default=None, alias="Round2InjIsolevel")
    scabbing: Optional[NSB2019Scabbing] = Field(default=None, alias="Scabbing")
    second_inj_recover: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="SecondInjRecover")
    second_injection_iso_duration: Optional[StrictStr] = Field(default=None, alias="SecondInjectionIsoDuration")
    second_injection_weight_after: Optional[StrictStr] = Field(default=None, alias="SecondInjectionWeightAfter")
    second_injection_weight_before: Optional[StrictStr] = Field(default=None, alias="SecondInjectionWeightBefore")
    second_round_ionto_issue: Optional[NSB2019SecondRoundIontoIssue] = Field(default=None, alias="SecondRoundIontoIssue")
    sex: Optional[NSB2019Sex] = Field(default=None, alias="Sex")
    st_round_injection_comments: Optional[StrictStr] = Field(default=None, alias="stRoundInjectionComments")
    start_x0020_of_x0020_week: Optional[datetime] = Field(default=None, alias="Start_x0020_Of_x0020_Week")
    surgery_status: Optional[NSB2019SurgeryStatus] = Field(default=None, alias="SurgeryStatus")
    title: Optional[StrictStr] = Field(default=None, alias="Title")
    touch_x0020_up_x0020__x0020_comp: Optional[datetime] = Field(default=None, alias="Touch_x0020_Up_x0020__x0020_Comp")
    touch_x0020_up_x0020_status: Optional[NSB2019TouchUpStatus] = Field(default=None, alias="Touch_x0020_Up_x0020_Status")
    touch_x0020_up_x0020_weight_x002: Optional[StrictStr] = Field(default=None, alias="Touch_x0020_Up_x0020_Weight_x002")
    ui_version_string: Optional[StrictStr] = Field(default=None, alias="_UIVersionString")
    virus_x0020_a_x002f_p: Optional[StrictStr] = Field(default=None, alias="Virus_x0020_A_x002f_P")
    virus_x0020_d_x002f_v: Optional[StrictStr] = Field(default=None, alias="Virus_x0020_D_x002f_V")
    virus_x0020_hemisphere: Optional[NSB2019Inj1Hemisphere] = Field(default=None, alias="Virus_x0020_Hemisphere")
    virus_x0020_m_x002f_l: Optional[StrictStr] = Field(default=None, alias="Virus_x0020_M_x002f_L")
    weight_x0020_after_x0020_surgery: Optional[StrictStr] = Field(default=None, alias="Weight_x0020_after_x0020_Surgery")
    weight_x0020_before_x0020_surger: Optional[StrictStr] = Field(default=None, alias="Weight_x0020_before_x0020_Surger")
    work_station1st_injection: Optional[NSB2019FirstRoundInjWorkstation] = Field(default=None, alias="WorkStation1stInjection")
    work_station2nd_injection: Optional[NSB2019SecondRoundWorkstation] = Field(default=None, alias="WorkStation2ndInjection")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["Age_x0020_at_x0020_Injection", "AP2ndInj", "AuthorId", "Breg2Lamb", "Cage", "_ColorTag", "ComAfter1stInj", "ComAfter2ndInj", "ComCoplanar", "ComDamage", "ComDuring1stInj", "ComDuring2ndInj", "ComDurotomy", "ComSinusbleed", "ComSwelling", "ComWindow", "ComplianceAssetId", "Contusion", "CraniotomyType", "Created", "Date1stInjection", "Date2ndInjection", "Date_x0020_of_x0020_Birth", "Date_x0020_of_x0020_Surgery", "DateRangeEnd", "DateRangeStart", "DV2ndInj", "EditorId", "End_x0020_of_x0020_Week", "Exudate_x0020_Severity", "Eye_x0020_Affected", "Eye_x0020_Issue", "FiberImplant1", "FiberImplant1DV", "FiberImplant2", "FiberImplant2DV", "field30", "field50", "FirstInjRecovery", "FirstInjectionIsoDuration", "FirstInjectionWeightAfter", "FirstInjectionWeightBefor", "FirstRoundIontoIssue", "HeadpostType", "Hemisphere2ndInj", "HP_x0020_A_x002f_P", "HP_x0020_Diameter", "HPDurotomy", "HP_x0020__x0026__x0020_Inj", "HPIsoLevel", "HpLoc", "HP_x0020_M_x002f_L", "HpPerf", "HpPrevInject", "HPRecovery", "_x0031_HP_x0020_Requestor_x0020_", "HPRequestorCommentsPlaintext", "HPSurgeonComments", "HpWorkStation", "IACUC_x0020_Protocol_x0020__x002", "ID", "ImplantIDCoverslipType", "Inj1AlternatingTime", "Inj1Angle_v2", "Inj1Current", "Inj1LenghtofTime", "Inj1Round", "Inj1StorageLocation", "Inj1Type", "Inj1VirusStrain_rt", "Inj1Vol", "Inj1angle0", "inj1volperdepth", "Inj2AlternatingTime", "Inj2Angle_v2", "Inj2Current", "Inj2LenghtofTime", "Inj2Round", "Inj2StorageLocation", "Inj2Type", "Inj2VirusStrain_rt", "Inj2Vol", "Inj2angle0", "inj2volperdepth", "IontoNumberHPINJ", "IontoNumberInj1", "IontoNumberInj2", "Iso_x0020_On", "Issue", "LabTracks_x0020_Group", "LabTracks_x0020_ID", "LabTracks_x0020_Requestor", "LIMs_x0020_Required", "Light_x0020_Cycle", "LIMStaskflow1", "LIMS_x0020_link", "Lims_x0020_Project_x0020_Code", "Long1stRoundInjCmts", "Long2ndRndInjCmts", "LongRequestorComments", "LongSurgeonComments", "ML2ndInj", "Modified", "NanojectNumberInj10", "NanojectNumberInj2", "ndRoungInjectionComments", "PedigreeName", "Procedure", "Project_x0020_ID_x0020__x0028_te", "retSetting0", "retSetting1", "Round1InjIsolevel", "Round2InjIsolevel", "Scabbing", "SecondInjRecover", "SecondInjectionIsoDuration", "SecondInjectionWeightAfter", "SecondInjectionWeightBefore", "SecondRoundIontoIssue", "Sex", "stRoundInjectionComments", "Start_x0020_Of_x0020_Week", "SurgeryStatus", "Title", "Touch_x0020_Up_x0020__x0020_Comp", "Touch_x0020_Up_x0020_Status", "Touch_x0020_Up_x0020_Weight_x002", "_UIVersionString", "Virus_x0020_A_x002f_P", "Virus_x0020_D_x002f_V", "Virus_x0020_Hemisphere", "Virus_x0020_M_x002f_L", "Weight_x0020_after_x0020_Surgery", "Weight_x0020_before_x0020_Surger", "WorkStation1stInjection", "WorkStation2ndInjection"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NSB2019List from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        # set to None if age_x0020_at_x0020_injection (nullable) is None
        # and model_fields_set contains the field
        if self.age_x0020_at_x0020_injection is None and "age_x0020_at_x0020_injection" in self.model_fields_set:
            _dict['Age_x0020_at_x0020_Injection'] = None

        # set to None if ap2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.ap2nd_inj is None and "ap2nd_inj" in self.model_fields_set:
            _dict['AP2ndInj'] = None

        # set to None if author_id (nullable) is None
        # and model_fields_set contains the field
        if self.author_id is None and "author_id" in self.model_fields_set:
            _dict['AuthorId'] = None

        # set to None if breg2_lamb (nullable) is None
        # and model_fields_set contains the field
        if self.breg2_lamb is None and "breg2_lamb" in self.model_fields_set:
            _dict['Breg2Lamb'] = None

        # set to None if cage (nullable) is None
        # and model_fields_set contains the field
        if self.cage is None and "cage" in self.model_fields_set:
            _dict['Cage'] = None

        # set to None if color_tag (nullable) is None
        # and model_fields_set contains the field
        if self.color_tag is None and "color_tag" in self.model_fields_set:
            _dict['_ColorTag'] = None

        # set to None if compliance_asset_id (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_asset_id is None and "compliance_asset_id" in self.model_fields_set:
            _dict['ComplianceAssetId'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['Created'] = None

        # set to None if date1st_injection (nullable) is None
        # and model_fields_set contains the field
        if self.date1st_injection is None and "date1st_injection" in self.model_fields_set:
            _dict['Date1stInjection'] = None

        # set to None if date2nd_injection (nullable) is None
        # and model_fields_set contains the field
        if self.date2nd_injection is None and "date2nd_injection" in self.model_fields_set:
            _dict['Date2ndInjection'] = None

        # set to None if date_x0020_of_x0020_birth (nullable) is None
        # and model_fields_set contains the field
        if self.date_x0020_of_x0020_birth is None and "date_x0020_of_x0020_birth" in self.model_fields_set:
            _dict['Date_x0020_of_x0020_Birth'] = None

        # set to None if date_x0020_of_x0020_surgery (nullable) is None
        # and model_fields_set contains the field
        if self.date_x0020_of_x0020_surgery is None and "date_x0020_of_x0020_surgery" in self.model_fields_set:
            _dict['Date_x0020_of_x0020_Surgery'] = None

        # set to None if date_range_end (nullable) is None
        # and model_fields_set contains the field
        if self.date_range_end is None and "date_range_end" in self.model_fields_set:
            _dict['DateRangeEnd'] = None

        # set to None if date_range_start (nullable) is None
        # and model_fields_set contains the field
        if self.date_range_start is None and "date_range_start" in self.model_fields_set:
            _dict['DateRangeStart'] = None

        # set to None if dv2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.dv2nd_inj is None and "dv2nd_inj" in self.model_fields_set:
            _dict['DV2ndInj'] = None

        # set to None if editor_id (nullable) is None
        # and model_fields_set contains the field
        if self.editor_id is None and "editor_id" in self.model_fields_set:
            _dict['EditorId'] = None

        # set to None if end_x0020_of_x0020_week (nullable) is None
        # and model_fields_set contains the field
        if self.end_x0020_of_x0020_week is None and "end_x0020_of_x0020_week" in self.model_fields_set:
            _dict['End_x0020_of_x0020_Week'] = None

        # set to None if fiber_implant1 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant1 is None and "fiber_implant1" in self.model_fields_set:
            _dict['FiberImplant1'] = None

        # set to None if fiber_implant1_dv (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant1_dv is None and "fiber_implant1_dv" in self.model_fields_set:
            _dict['FiberImplant1DV'] = None

        # set to None if fiber_implant2 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant2 is None and "fiber_implant2" in self.model_fields_set:
            _dict['FiberImplant2'] = None

        # set to None if fiber_implant2_dv (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant2_dv is None and "fiber_implant2_dv" in self.model_fields_set:
            _dict['FiberImplant2DV'] = None

        # set to None if field30 (nullable) is None
        # and model_fields_set contains the field
        if self.field30 is None and "field30" in self.model_fields_set:
            _dict['field30'] = None

        # set to None if field50 (nullable) is None
        # and model_fields_set contains the field
        if self.field50 is None and "field50" in self.model_fields_set:
            _dict['field50'] = None

        # set to None if first_inj_recovery (nullable) is None
        # and model_fields_set contains the field
        if self.first_inj_recovery is None and "first_inj_recovery" in self.model_fields_set:
            _dict['FirstInjRecovery'] = None

        # set to None if first_injection_iso_duration (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_iso_duration is None and "first_injection_iso_duration" in self.model_fields_set:
            _dict['FirstInjectionIsoDuration'] = None

        # set to None if first_injection_weight_after (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_weight_after is None and "first_injection_weight_after" in self.model_fields_set:
            _dict['FirstInjectionWeightAfter'] = None

        # set to None if first_injection_weight_befor (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_weight_befor is None and "first_injection_weight_befor" in self.model_fields_set:
            _dict['FirstInjectionWeightBefor'] = None

        # set to None if hp_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.hp_x0020_a_x002f_p is None and "hp_x0020_a_x002f_p" in self.model_fields_set:
            _dict['HP_x0020_A_x002f_P'] = None

        # set to None if hp_x0020_diameter (nullable) is None
        # and model_fields_set contains the field
        if self.hp_x0020_diameter is None and "hp_x0020_diameter" in self.model_fields_set:
            _dict['HP_x0020_Diameter'] = None

        # set to None if hp_x0020__x0026__x0020_inj (nullable) is None
        # and model_fields_set contains the field
        if self.hp_x0020__x0026__x0020_inj is None and "hp_x0020__x0026__x0020_inj" in self.model_fields_set:
            _dict['HP_x0020__x0026__x0020_Inj'] = None

        # set to None if hp_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.hp_x0020_m_x002f_l is None and "hp_x0020_m_x002f_l" in self.model_fields_set:
            _dict['HP_x0020_M_x002f_L'] = None

        # set to None if hp_recovery (nullable) is None
        # and model_fields_set contains the field
        if self.hp_recovery is None and "hp_recovery" in self.model_fields_set:
            _dict['HPRecovery'] = None

        # set to None if x0031_hp_x0020_requestor_x0020_ (nullable) is None
        # and model_fields_set contains the field
        if self.x0031_hp_x0020_requestor_x0020_ is None and "x0031_hp_x0020_requestor_x0020_" in self.model_fields_set:
            _dict['_x0031_HP_x0020_Requestor_x0020_'] = None

        # set to None if hp_requestor_comments_plaintext (nullable) is None
        # and model_fields_set contains the field
        if self.hp_requestor_comments_plaintext is None and "hp_requestor_comments_plaintext" in self.model_fields_set:
            _dict['HPRequestorCommentsPlaintext'] = None

        # set to None if hp_surgeon_comments (nullable) is None
        # and model_fields_set contains the field
        if self.hp_surgeon_comments is None and "hp_surgeon_comments" in self.model_fields_set:
            _dict['HPSurgeonComments'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['ID'] = None

        # set to None if inj1_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_alternating_time is None and "inj1_alternating_time" in self.model_fields_set:
            _dict['Inj1AlternatingTime'] = None

        # set to None if inj1_angle_v2 (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_angle_v2 is None and "inj1_angle_v2" in self.model_fields_set:
            _dict['Inj1Angle_v2'] = None

        # set to None if inj1_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_current is None and "inj1_current" in self.model_fields_set:
            _dict['Inj1Current'] = None

        # set to None if inj1_lenghtof_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_lenghtof_time is None and "inj1_lenghtof_time" in self.model_fields_set:
            _dict['Inj1LenghtofTime'] = None

        # set to None if inj1_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_storage_location is None and "inj1_storage_location" in self.model_fields_set:
            _dict['Inj1StorageLocation'] = None

        # set to None if inj1_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_virus_strain_rt is None and "inj1_virus_strain_rt" in self.model_fields_set:
            _dict['Inj1VirusStrain_rt'] = None

        # set to None if inj1_vol (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_vol is None and "inj1_vol" in self.model_fields_set:
            _dict['Inj1Vol'] = None

        # set to None if inj1volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj1volperdepth is None and "inj1volperdepth" in self.model_fields_set:
            _dict['inj1volperdepth'] = None

        # set to None if inj2_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_alternating_time is None and "inj2_alternating_time" in self.model_fields_set:
            _dict['Inj2AlternatingTime'] = None

        # set to None if inj2_angle_v2 (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_angle_v2 is None and "inj2_angle_v2" in self.model_fields_set:
            _dict['Inj2Angle_v2'] = None

        # set to None if inj2_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_current is None and "inj2_current" in self.model_fields_set:
            _dict['Inj2Current'] = None

        # set to None if inj2_lenghtof_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_lenghtof_time is None and "inj2_lenghtof_time" in self.model_fields_set:
            _dict['Inj2LenghtofTime'] = None

        # set to None if inj2_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_storage_location is None and "inj2_storage_location" in self.model_fields_set:
            _dict['Inj2StorageLocation'] = None

        # set to None if inj2_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_virus_strain_rt is None and "inj2_virus_strain_rt" in self.model_fields_set:
            _dict['Inj2VirusStrain_rt'] = None

        # set to None if inj2_vol (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_vol is None and "inj2_vol" in self.model_fields_set:
            _dict['Inj2Vol'] = None

        # set to None if inj2volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj2volperdepth is None and "inj2volperdepth" in self.model_fields_set:
            _dict['inj2volperdepth'] = None

        # set to None if iso_x0020_on (nullable) is None
        # and model_fields_set contains the field
        if self.iso_x0020_on is None and "iso_x0020_on" in self.model_fields_set:
            _dict['Iso_x0020_On'] = None

        # set to None if lab_tracks_x0020_group (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_group is None and "lab_tracks_x0020_group" in self.model_fields_set:
            _dict['LabTracks_x0020_Group'] = None

        # set to None if lab_tracks_x0020_id (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_id is None and "lab_tracks_x0020_id" in self.model_fields_set:
            _dict['LabTracks_x0020_ID'] = None

        # set to None if lab_tracks_x0020_requestor (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_requestor is None and "lab_tracks_x0020_requestor" in self.model_fields_set:
            _dict['LabTracks_x0020_Requestor'] = None

        # set to None if lims_x0020_link (nullable) is None
        # and model_fields_set contains the field
        if self.lims_x0020_link is None and "lims_x0020_link" in self.model_fields_set:
            _dict['LIMS_x0020_link'] = None

        # set to None if long1st_round_inj_cmts (nullable) is None
        # and model_fields_set contains the field
        if self.long1st_round_inj_cmts is None and "long1st_round_inj_cmts" in self.model_fields_set:
            _dict['Long1stRoundInjCmts'] = None

        # set to None if long2nd_rnd_inj_cmts (nullable) is None
        # and model_fields_set contains the field
        if self.long2nd_rnd_inj_cmts is None and "long2nd_rnd_inj_cmts" in self.model_fields_set:
            _dict['Long2ndRndInjCmts'] = None

        # set to None if long_requestor_comments (nullable) is None
        # and model_fields_set contains the field
        if self.long_requestor_comments is None and "long_requestor_comments" in self.model_fields_set:
            _dict['LongRequestorComments'] = None

        # set to None if long_surgeon_comments (nullable) is None
        # and model_fields_set contains the field
        if self.long_surgeon_comments is None and "long_surgeon_comments" in self.model_fields_set:
            _dict['LongSurgeonComments'] = None

        # set to None if ml2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.ml2nd_inj is None and "ml2nd_inj" in self.model_fields_set:
            _dict['ML2ndInj'] = None

        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['Modified'] = None

        # set to None if nd_roung_injection_comments (nullable) is None
        # and model_fields_set contains the field
        if self.nd_roung_injection_comments is None and "nd_roung_injection_comments" in self.model_fields_set:
            _dict['ndRoungInjectionComments'] = None

        # set to None if pedigree_name (nullable) is None
        # and model_fields_set contains the field
        if self.pedigree_name is None and "pedigree_name" in self.model_fields_set:
            _dict['PedigreeName'] = None

        # set to None if second_inj_recover (nullable) is None
        # and model_fields_set contains the field
        if self.second_inj_recover is None and "second_inj_recover" in self.model_fields_set:
            _dict['SecondInjRecover'] = None

        # set to None if second_injection_iso_duration (nullable) is None
        # and model_fields_set contains the field
        if self.second_injection_iso_duration is None and "second_injection_iso_duration" in self.model_fields_set:
            _dict['SecondInjectionIsoDuration'] = None

        # set to None if second_injection_weight_after (nullable) is None
        # and model_fields_set contains the field
        if self.second_injection_weight_after is None and "second_injection_weight_after" in self.model_fields_set:
            _dict['SecondInjectionWeightAfter'] = None

        # set to None if second_injection_weight_before (nullable) is None
        # and model_fields_set contains the field
        if self.second_injection_weight_before is None and "second_injection_weight_before" in self.model_fields_set:
            _dict['SecondInjectionWeightBefore'] = None

        # set to None if st_round_injection_comments (nullable) is None
        # and model_fields_set contains the field
        if self.st_round_injection_comments is None and "st_round_injection_comments" in self.model_fields_set:
            _dict['stRoundInjectionComments'] = None

        # set to None if start_x0020_of_x0020_week (nullable) is None
        # and model_fields_set contains the field
        if self.start_x0020_of_x0020_week is None and "start_x0020_of_x0020_week" in self.model_fields_set:
            _dict['Start_x0020_Of_x0020_Week'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['Title'] = None

        # set to None if touch_x0020_up_x0020__x0020_comp (nullable) is None
        # and model_fields_set contains the field
        if self.touch_x0020_up_x0020__x0020_comp is None and "touch_x0020_up_x0020__x0020_comp" in self.model_fields_set:
            _dict['Touch_x0020_Up_x0020__x0020_Comp'] = None

        # set to None if touch_x0020_up_x0020_weight_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.touch_x0020_up_x0020_weight_x002 is None and "touch_x0020_up_x0020_weight_x002" in self.model_fields_set:
            _dict['Touch_x0020_Up_x0020_Weight_x002'] = None

        # set to None if ui_version_string (nullable) is None
        # and model_fields_set contains the field
        if self.ui_version_string is None and "ui_version_string" in self.model_fields_set:
            _dict['_UIVersionString'] = None

        # set to None if virus_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_a_x002f_p is None and "virus_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Virus_x0020_A_x002f_P'] = None

        # set to None if virus_x0020_d_x002f_v (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_d_x002f_v is None and "virus_x0020_d_x002f_v" in self.model_fields_set:
            _dict['Virus_x0020_D_x002f_V'] = None

        # set to None if virus_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_m_x002f_l is None and "virus_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Virus_x0020_M_x002f_L'] = None

        # set to None if weight_x0020_after_x0020_surgery (nullable) is None
        # and model_fields_set contains the field
        if self.weight_x0020_after_x0020_surgery is None and "weight_x0020_after_x0020_surgery" in self.model_fields_set:
            _dict['Weight_x0020_after_x0020_Surgery'] = None

        # set to None if weight_x0020_before_x0020_surger (nullable) is None
        # and model_fields_set contains the field
        if self.weight_x0020_before_x0020_surger is None and "weight_x0020_before_x0020_surger" in self.model_fields_set:
            _dict['Weight_x0020_before_x0020_Surger'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NSB2019List from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Age_x0020_at_x0020_Injection": obj.get("Age_x0020_at_x0020_Injection"),
            "AP2ndInj": obj.get("AP2ndInj"),
            "AuthorId": obj.get("AuthorId"),
            "Breg2Lamb": obj.get("Breg2Lamb"),
            "Cage": obj.get("Cage"),
            "_ColorTag": obj.get("_ColorTag"),
            "ComAfter1stInj": obj.get("ComAfter1stInj"),
            "ComAfter2ndInj": obj.get("ComAfter2ndInj"),
            "ComCoplanar": obj.get("ComCoplanar"),
            "ComDamage": obj.get("ComDamage"),
            "ComDuring1stInj": obj.get("ComDuring1stInj"),
            "ComDuring2ndInj": obj.get("ComDuring2ndInj"),
            "ComDurotomy": obj.get("ComDurotomy"),
            "ComSinusbleed": obj.get("ComSinusbleed"),
            "ComSwelling": obj.get("ComSwelling"),
            "ComWindow": obj.get("ComWindow"),
            "ComplianceAssetId": obj.get("ComplianceAssetId"),
            "Contusion": obj.get("Contusion"),
            "CraniotomyType": obj.get("CraniotomyType"),
            "Created": obj.get("Created"),
            "Date1stInjection": obj.get("Date1stInjection"),
            "Date2ndInjection": obj.get("Date2ndInjection"),
            "Date_x0020_of_x0020_Birth": obj.get("Date_x0020_of_x0020_Birth"),
            "Date_x0020_of_x0020_Surgery": obj.get("Date_x0020_of_x0020_Surgery"),
            "DateRangeEnd": obj.get("DateRangeEnd"),
            "DateRangeStart": obj.get("DateRangeStart"),
            "DV2ndInj": obj.get("DV2ndInj"),
            "EditorId": obj.get("EditorId"),
            "End_x0020_of_x0020_Week": obj.get("End_x0020_of_x0020_Week"),
            "Exudate_x0020_Severity": obj.get("Exudate_x0020_Severity"),
            "Eye_x0020_Affected": obj.get("Eye_x0020_Affected"),
            "Eye_x0020_Issue": obj.get("Eye_x0020_Issue"),
            "FiberImplant1": obj.get("FiberImplant1"),
            "FiberImplant1DV": obj.get("FiberImplant1DV"),
            "FiberImplant2": obj.get("FiberImplant2"),
            "FiberImplant2DV": obj.get("FiberImplant2DV"),
            "field30": obj.get("field30"),
            "field50": obj.get("field50"),
            "FirstInjRecovery": obj.get("FirstInjRecovery"),
            "FirstInjectionIsoDuration": obj.get("FirstInjectionIsoDuration"),
            "FirstInjectionWeightAfter": obj.get("FirstInjectionWeightAfter"),
            "FirstInjectionWeightBefor": obj.get("FirstInjectionWeightBefor"),
            "FirstRoundIontoIssue": obj.get("FirstRoundIontoIssue"),
            "HeadpostType": obj.get("HeadpostType"),
            "Hemisphere2ndInj": obj.get("Hemisphere2ndInj"),
            "HP_x0020_A_x002f_P": obj.get("HP_x0020_A_x002f_P"),
            "HP_x0020_Diameter": obj.get("HP_x0020_Diameter"),
            "HPDurotomy": obj.get("HPDurotomy"),
            "HP_x0020__x0026__x0020_Inj": obj.get("HP_x0020__x0026__x0020_Inj"),
            "HPIsoLevel": obj.get("HPIsoLevel"),
            "HpLoc": obj.get("HpLoc"),
            "HP_x0020_M_x002f_L": obj.get("HP_x0020_M_x002f_L"),
            "HpPerf": obj.get("HpPerf"),
            "HpPrevInject": obj.get("HpPrevInject"),
            "HPRecovery": obj.get("HPRecovery"),
            "_x0031_HP_x0020_Requestor_x0020_": obj.get("_x0031_HP_x0020_Requestor_x0020_"),
            "HPRequestorCommentsPlaintext": obj.get("HPRequestorCommentsPlaintext"),
            "HPSurgeonComments": obj.get("HPSurgeonComments"),
            "HpWorkStation": obj.get("HpWorkStation"),
            "IACUC_x0020_Protocol_x0020__x002": obj.get("IACUC_x0020_Protocol_x0020__x002"),
            "ID": obj.get("ID"),
            "ImplantIDCoverslipType": obj.get("ImplantIDCoverslipType"),
            "Inj1AlternatingTime": obj.get("Inj1AlternatingTime"),
            "Inj1Angle_v2": obj.get("Inj1Angle_v2"),
            "Inj1Current": obj.get("Inj1Current"),
            "Inj1LenghtofTime": obj.get("Inj1LenghtofTime"),
            "Inj1Round": obj.get("Inj1Round"),
            "Inj1StorageLocation": obj.get("Inj1StorageLocation"),
            "Inj1Type": obj.get("Inj1Type"),
            "Inj1VirusStrain_rt": obj.get("Inj1VirusStrain_rt"),
            "Inj1Vol": obj.get("Inj1Vol"),
            "Inj1angle0": obj.get("Inj1angle0"),
            "inj1volperdepth": obj.get("inj1volperdepth"),
            "Inj2AlternatingTime": obj.get("Inj2AlternatingTime"),
            "Inj2Angle_v2": obj.get("Inj2Angle_v2"),
            "Inj2Current": obj.get("Inj2Current"),
            "Inj2LenghtofTime": obj.get("Inj2LenghtofTime"),
            "Inj2Round": obj.get("Inj2Round"),
            "Inj2StorageLocation": obj.get("Inj2StorageLocation"),
            "Inj2Type": obj.get("Inj2Type"),
            "Inj2VirusStrain_rt": obj.get("Inj2VirusStrain_rt"),
            "Inj2Vol": obj.get("Inj2Vol"),
            "Inj2angle0": obj.get("Inj2angle0"),
            "inj2volperdepth": obj.get("inj2volperdepth"),
            "IontoNumberHPINJ": obj.get("IontoNumberHPINJ"),
            "IontoNumberInj1": obj.get("IontoNumberInj1"),
            "IontoNumberInj2": obj.get("IontoNumberInj2"),
            "Iso_x0020_On": obj.get("Iso_x0020_On"),
            "Issue": obj.get("Issue"),
            "LabTracks_x0020_Group": obj.get("LabTracks_x0020_Group"),
            "LabTracks_x0020_ID": obj.get("LabTracks_x0020_ID"),
            "LabTracks_x0020_Requestor": obj.get("LabTracks_x0020_Requestor"),
            "LIMs_x0020_Required": obj.get("LIMs_x0020_Required"),
            "Light_x0020_Cycle": obj.get("Light_x0020_Cycle"),
            "LIMStaskflow1": obj.get("LIMStaskflow1"),
            "LIMS_x0020_link": obj.get("LIMS_x0020_link"),
            "Lims_x0020_Project_x0020_Code": obj.get("Lims_x0020_Project_x0020_Code"),
            "Long1stRoundInjCmts": obj.get("Long1stRoundInjCmts"),
            "Long2ndRndInjCmts": obj.get("Long2ndRndInjCmts"),
            "LongRequestorComments": obj.get("LongRequestorComments"),
            "LongSurgeonComments": obj.get("LongSurgeonComments"),
            "ML2ndInj": obj.get("ML2ndInj"),
            "Modified": obj.get("Modified"),
            "NanojectNumberInj10": obj.get("NanojectNumberInj10"),
            "NanojectNumberInj2": obj.get("NanojectNumberInj2"),
            "ndRoungInjectionComments": obj.get("ndRoungInjectionComments"),
            "PedigreeName": obj.get("PedigreeName"),
            "Procedure": obj.get("Procedure"),
            "Project_x0020_ID_x0020__x0028_te": obj.get("Project_x0020_ID_x0020__x0028_te"),
            "retSetting0": obj.get("retSetting0"),
            "retSetting1": obj.get("retSetting1"),
            "Round1InjIsolevel": obj.get("Round1InjIsolevel"),
            "Round2InjIsolevel": obj.get("Round2InjIsolevel"),
            "Scabbing": obj.get("Scabbing"),
            "SecondInjRecover": obj.get("SecondInjRecover"),
            "SecondInjectionIsoDuration": obj.get("SecondInjectionIsoDuration"),
            "SecondInjectionWeightAfter": obj.get("SecondInjectionWeightAfter"),
            "SecondInjectionWeightBefore": obj.get("SecondInjectionWeightBefore"),
            "SecondRoundIontoIssue": obj.get("SecondRoundIontoIssue"),
            "Sex": obj.get("Sex"),
            "stRoundInjectionComments": obj.get("stRoundInjectionComments"),
            "Start_x0020_Of_x0020_Week": obj.get("Start_x0020_Of_x0020_Week"),
            "SurgeryStatus": obj.get("SurgeryStatus"),
            "Title": obj.get("Title"),
            "Touch_x0020_Up_x0020__x0020_Comp": obj.get("Touch_x0020_Up_x0020__x0020_Comp"),
            "Touch_x0020_Up_x0020_Status": obj.get("Touch_x0020_Up_x0020_Status"),
            "Touch_x0020_Up_x0020_Weight_x002": obj.get("Touch_x0020_Up_x0020_Weight_x002"),
            "_UIVersionString": obj.get("_UIVersionString"),
            "Virus_x0020_A_x002f_P": obj.get("Virus_x0020_A_x002f_P"),
            "Virus_x0020_D_x002f_V": obj.get("Virus_x0020_D_x002f_V"),
            "Virus_x0020_Hemisphere": obj.get("Virus_x0020_Hemisphere"),
            "Virus_x0020_M_x002f_L": obj.get("Virus_x0020_M_x002f_L"),
            "Weight_x0020_after_x0020_Surgery": obj.get("Weight_x0020_after_x0020_Surgery"),
            "Weight_x0020_before_x0020_Surger": obj.get("Weight_x0020_before_x0020_Surger"),
            "WorkStation1stInjection": obj.get("WorkStation1stInjection"),
            "WorkStation2ndInjection": obj.get("WorkStation2ndInjection")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023BehaviorType(str, Enum):
    """
    Enum class for NSB2023Behavior Type.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    FORAGING = 'Foraging'
    FORAGING_FP = 'Foraging + FP'
    WR__HAB = 'WR+Hab'
    HAB__ONLY = 'Hab Only'
    AIBS_CHARACTERIZATION_ROT = 'AIBS Characterization (Rotarod & Open Field)'
    AIND_FORAGING_TASK_WITH_O = 'AIND Foraging Task (with or without fiber photometry)'
    AIND_MOTOR_OBSERVATORY_WH = 'AIND Motor Observatory (Wheel & Open Field & Isometric Task)'
    CHANGE_DETECTION_TASK = 'Change Detection Task'
    DR_AUDITORY_VISUAL_TASK = 'DR Auditory/Visual Task'
    HABITUATION_ONLY = 'Habituation Only'
    HABITUATION_PASSIVE_TRAIN = 'Habituation + Passive Training'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023BehaviorType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019HeadpostType(str, Enum):
    """
    Enum class for HeadpostType
    """

    """
    allowed enum values
    """
    AI_STRAIGHT_HEADBAR = 'AI Straight Headbar'
    CAMSTYLE_HEADFRAME_016010 = 'CAM-style headframe (0160-100-10 Rev A)'
    MESOSCOPESTYLE_WELL_WITH = 'Mesoscope-style well with NGC-style headframe (0160-200-20/0160-100-10)'
    NEUROPIXELSTYLE_HEADFRAME = 'Neuropixel-style headframe (0160-100-10/0160-200-36)'
    NGCSTYLE_HEADFRAME_NO_WEL = 'NGC-style headframe, no well (0160-100-10)'
    SELECT = 'Select...'
    WHC_42_WITH_NEUROPIXEL_WE = 'WHC #42 with Neuropixel well and well cap'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019HeadpostType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProtocol(str, Enum):
    """
    Enum class for Protocol.
    """

    """
    allowed enum values
    """
    N_2207_IN_VITRO_BRAIN = '2207 - In Vitro Brain Stimulation'
    N_2212_INVESTIGATING_BR = '2212 - Investigating Brain States'
    N_2301_TESTING_OF_ENHANC = '2301 - Testing of enhancers and AAV gene therapy vectors'
    N_2304_NEUROSURGERY_BEH = '2304 - Neurosurgery & Behavior Training Protocol'
    N_2305_IN_VIVO_BRAIN = '2305 - In Vivo Brain Stimulation'
    N_2306_PATCH_SEQ_CHARACT = '2306 - Patch-seq characterization of mouse neurons in acute brain slices for cross-species comparison studies'
    N_2307_DISSECTING_THE_NE = '2307 - Dissecting the neural circuits of adaptive control of behavior'
    N_2308_INDUCTION_OF_IMM = '2308 - Induction of Immune Memory'
    N_2401_THE_USE_OF_MICE_F = '2401 - The use of mice for the development of biological recorders'
    N_2402_BRAIN_OBSERVATOR = '2402 - Brain Observatory Optical Physiology'
    N_2403_ELECTROPHYSIOLOGY = '2403 - Electrophysiology Mindscope Phase 4'
    N_2405_ANALYSIS_OF_INTE = '2405 - Analysis of Integrated Neuronal Phenotypes'
    N_2406_CHARACTERIZATION = '2406 - Characterization of mouse and viral genetic tools'
    N_2410_VALIDATION_OF_BRA = '2410 - Validation of brain cell type enhancer AAV vectors in rats'
    N_2412_CIRCUIT_TRACING_A = '2412 - Circuit tracing and optical physiology of mouse cortex'
    N_2413_NEUROPHYSIOLOGY_O = '2413 - Neurophysiology of Naturalistic Learning'
    N_2414_ELECTROPHYSIOLOGI = '2414 - Electrophysiological and optical interrogation of brain-wide neural circuits in the mouse'
    N_2415_OPTOPHYSIOLOGICAL = '2415 - Optophysiological analysis of brain-wide neural circuits in the mouse'
    N_2416_ANATOMICAL_ANALYS = '2416 - Anatomical analysis of brain-wide neural circuits in the mouse'
    N_2417_CHARACTERIZATION = '2417 - Characterization of transcriptomic cell type activation and their molecular adaptations that occur during psychedelic, antidepressants, and antipsychotic drug use'
    N_2418_IN_VITRO_SINGLE = '2418 - In Vitro Single Cell Characterization'
    N_2427_OPEN_SCOPE_MINDS = '2427 - OpenScope Mindscope animal protocol for Optical Physiology and Neuropixel'
    N_2453_MOUSE_BREEDING = '2453 - Mouse Breeding'
    N_2457_TRAINING_AND_QUAL = '2457 - Training and qualification of animal users'
    N_2459_SPATIAL_CONNECTOM = '2459 - Spatial, connectomic and molecular characterization of spinal cord and sympathetic nervous system'
    N_2505_TESTING_AA_VS_IN = '2505 - Testing AAVs in Parkinson\'s mouse models'
    N_2511_DISSECTING_THE_NE = '2511 - Dissecting the neural circuits of motor learning and control'
    N_2530_DEVELOPMENT_OF_T = '2530 - Development of Transgenic Technologies & Methodologies'
    N_2538_INTERROGATING_PRO = '2538 - Interrogating projections and gene expression of neurons by in situ sequencing'
    N_2547_PROTEOMIC_EXPLORA = '2547 - Proteomic exploration of cell types'
    N_2577_IN_VITRO_BRAIN = '2577 - In Vitro Brain Stimulation'
    N_2580_OPTIMIZATION_AND = '2580 - Optimization and validation of viral vectors'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProtocol from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023ImplantIdCoverslipType(str, Enum):
    """
    Enum class for Implant ID/Coverslip type.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    N_2002 = '2002'
    N_2005 = '2005'
    N_2006 = '2006'
    N_2011 = '2011'
    N_2013 = '2013'
    N_2014 = '2014'
    N_2015 = '2015'
    N_3003 = '3003'
    N_3004 = '3004'
    N_3004_25_PURALUBE_SYSTAN = '3004 (25% puralube/systane)'
    N_3005 = '3005'
    N_3006 = '3006'
    N_3007 = '3007'
    N_3008 = '3008'
    WHC_2_P_CURVED_GLASS_WITH = 'WHC 2P curved glass (with window frame)'
    N_3MM_STACKED_COVERSLIP = '3mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP = '5mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP_W = '5mm stacked coverslip (with silicone coating for Neuropixel)'
    N_2001 = '2001'
    N_2004 = '2004'
    N_2010 = '2010'
    N_3001 = '3001'
    N_2007 = '2007'
    N_2008 = '2008'
    N_2009 = '2009'
    N_3002 = '3002'
    N_3002_25_PURALUBESYSTANE = '3002 (25% puralube/systane)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023ImplantIdCoverslipType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASPostfix(str, Enum):
    """
    Enum class for PostFix.
    """

    """
    allowed enum values
    """
    N_30_SUCROSE = '30% Sucrose'
    N_30_SUCROSE_FOIL_WRAPPE = '30% Sucrose (foil-wrapped tube)'
    N_1X_PBS = '1xPBS'
    N_1X_PBS_FOIL_WRAPPED_TUB = '1xPBS (foil-wrapped tube)'
    N_1X_PBS_0_01_AZIDE = '1xPBS+ 0.01%Azide'
    N_1X_PBS_0_01_AZIDE_5M_L = '1xPBS+ 0.01%Azide (5mL tubes)'
    N_1X_PBS_0_01_AZIDE_FOIL = '1xPBS+ 0.01%Azide (foil-wrapped tube)'
    N_4_PFA_TO_1X_PBS = '4%PFA to 1xPBS'
    NUCLEASE_FREE_1X_PBS_OM_F = 'Nuclease-free 1xPBS (omFISH)'
    NUCLEASE_FREE_30_SUCROSE = 'Nuclease-free 30% Sucrose'
    NUCLEASE_FREE_30_SUCROSE_2 = 'Nuclease-free 30% Sucrose(FOIL)'
    DPBS_NUCLEASE_FREE = 'DPBS(Nuclease-free)'
    OTHER_SPECIFY_BELOW = 'Other (Specify below)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASPostfix from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Limstaskflow(str, Enum):
    """
    Enum class for Limstaskflow
    """

    """
    allowed enum values
    """
    AIND_EPHYS_PASSIVE_BEHAVI = 'AIND Ephys (Passive Behavior)'
    AIND_EPHYS_SURGERY_ONLY = 'AIND Ephys (Surgery only)'
    AIND_U19_THALAMUS = 'AIND U19 Thalamus'
    BRAIN_LARGE_SCALE_RECORDI = 'BRAIN Large Scale Recording'
    BRAIN_MOUSE_BRAIN_CELL_AT = 'BRAIN Mouse Brain Cell Atlas trans-synaptic'
    BRAIN_OBSERVATORY_TRANSGE = 'Brain Observatory Transgenic Characterization'
    BTV_BRAIN_VIRAL_STRATEGIE = 'BTV BRAIN Viral Strategies'
    CITRIC_ACID_PILOT = 'Citric Acid Pilot'
    EPHYS_TASK_DEV_DYNAMIC_RO = 'Ephys Task Dev Dynamic Routing (NSB Beh)'
    EPHYS_TASK_DEV_DYNAMI_001 = 'Ephys Task Dev Dynamic Routing (S/C Beh)'
    EPHYS_TAS_DEV_DYNAMIC_ROU = 'Ephys Tas Dev Dynamic Routing DOC Left Eye'
    IVSCC_HVA_RETRO_PATCH_SEQ = 'IVSCC HVA Retro PatchSeq'
    IVSC_CM_INJECTION = 'IVSCCm injection'
    IVSP_CM_INJECTION = 'IVSPCm Injection'
    MGT_ANTEROGRADE_PROJECTIO = 'MGT Anterograde Projection Mapping'
    MGT_LAB = 'MGT Lab'
    MGT_TISSUE_CYTE = 'MGT TissueCyte'
    MSP_DYNAMIC_ROUTING_SURGI = 'MSP Dynamic Routing Surgical Development'
    MSP_DYNAMIC_ROUTING_TASK = 'MSP Dynamic Routing Task 1 Production'
    MSP_DYNAMIC_ROUTING_ULTRA = 'MSP Dynamic Routing Ultra Optotagging Behavior'
    MSP_LEARNING_M_FISH_DEVEL = 'MSP Learning & mFISH Development (Dox)'
    MSP_LEARNING_M_FISH_D_001 = 'MSP Learning & mFISH Development'
    MSP_LEARNING_M_FISH_FRONT = 'MSP Learning & mFISH Frontal Window Dev'
    MSP_LEARNING_M_FISH_VIRUS = 'MSP Learning & mFISH Virus Testing'
    MSP_OM_FISH_CO_REGISTRATI = 'MSP omFISH Co-Registration Pilot'
    MSP_OM_FISH_CUX2_PILOT = 'MSP omFISH Cux2 Pilot'
    MSP_OM_FISH_GAD2_PILOT = 'MSP omFISH Gad2 Pilot'
    MSP_OM_FISH_ROB_INJECTION = 'MSP omFISH ROB Injection Virus Pilot'
    MSP_OM_FISH_RORB_PILOT = 'MSP omFISH Rorb Pilot'
    MSP_OPEN_SCOPE_DENDRITE_C = 'MSP OpenScope Dendrite Coupling'
    MSP_OPEN_SCOPE_GLOBAL_001 = 'MSP OpenScope Global Local Oddballs (Cohort 2)'
    MSP_OPEN_SCOPE_GLOBAL_LOC = 'MSP OpenScope Global Local Oddballs (Cohort 1)'
    MSP_OPEN_SCOPE_ILLUSION = 'MSP OpenScope Illusion'
    MSP_TASK_TRAINED_NETWORKS = 'MSP Task Trained Networks Neuropixel'
    MSP_TASK_TRAINED_NETW_001 = 'MSP Task Trained Networks Multiscope'
    MSP_VARIABILITY_AIM_1 = 'MSP Variability Aim 1'
    MSP_VARIABILITY_AIM_1_PIL = 'MSP Variability Aim 1 Pilot'
    MSP_VARIABILITY_SPONTANEO = 'MSP Variability Spontaneous'
    MSP_VIP_AXONAL_V1 = 'MSP VIP Axonal V1'
    MSP_VIP_SOMATIC_V1 = 'MSP VIP Somatic V1'
    NA = 'N/A'
    OPENSCOPE_VIRUS_VALIDATIO = 'Openscope Virus Validation'
    TINY_BLUE_DOT_BEHAVIOR = 'Tiny Blue Dot Behavior'
    TRANSGENIC_CHARACTERIZATI = 'Transgenic Characterization (Passive)'
    VGT_ENHANCERS_TRANSSYNAPT = 'VGT Enhancers Transsynaptic'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Limstaskflow from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Procedure(str, Enum):
    """
    Enum class for NSB2023Procedure.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    SX__CUSTOM = 'Sx- Custom'
    SX_1__VISUAL__CTX_2_P = 'Sx-01 Visual Ctx 2P'
    SX_2__FRONTAL__CTX_2_P = 'Sx-02 Frontal Ctx 2P'
    SX_3__MOTOR__CTX_2_P = 'Sx-03 Motor Ctx 2P'
    SX_4_WHC_2_P = 'Sx-04 WHC 2P'
    SX_5_INJ__VISUAL__CTX_2_P = 'Sx-05 INJ + Visual Ctx 2P'
    SX_6__GRID_INJ_6_OR_9__VI = 'Sx-06 Grid INJ (6 or 9) + Visual Ctx 2P'
    SX_8_INJ__MOTOR__CTX_2_P = 'Sx-08 INJ + Motor Ctx 2P'
    SX_9__GRID_INJ_6_OR_9__MO = 'Sx-09 Grid INJ (6 or 9) + Motor Ctx 2P'
    SX_11_19_HP__ONLY = 'Sx-11&19 HP Only'
    SX_11_19_HP__TRANSCRANIAL = 'Sx-11&19 HP Transcranial'
    SX_12__STEREOTAXIC__INJEC = 'Sx-12 Stereotaxic Injection (with Headpost)'
    SX_14__VISUAL__CTX_NP = 'Sx-14 Visual Ctx NP'
    SX_15_WHC_NP = 'Sx-15 WHC NP'
    SX_16_INJ_WHC_NP = 'Sx-16 INJ + WHC NP'
    SX_17_DHC = 'Sx-17 DHC'
    SX_18_INJ_DHC = 'Sx-18 INJ+DHC'
    SX_21__FIBER__OPTIC__IMPL = 'Sx-21 Fiber Optic Implant (with Headpost)'
    SX_21__INJECTION__FIBER = 'Sx-21 Injection + Fiber Optic Implant (with Headpost)'
    SX_24__STEREOTAXIC_INJECT = 'Sx-24 Stereotaxic injections: 1 INJ material'
    SX_25__STEREOTAXIC_INJECT = 'Sx-25 Stereotaxic injections: 2+ INJ materials'
    SX_26_ISI_GUIDED__INJECTI = 'Sx-26 ISI-guided Injection (with Headpost)'
    SX__SPINAL__CORD_INJ = 'Sx- Spinal Cord INJ'
    SX_EMG__ARRAY = 'Sx- EMG Array'
    SX__TESTES__INJECTION = 'Sx- Testes Injection'
    SX__OVIDUCT__INJECTION = 'Sx- Oviduct Injection'
    CUSTOM = 'Custom'
    DHC = 'DHC'
    FIBER_OPTIC_IMPLANT_WITH = 'Fiber Optic Implant (with Headpost)'
    FRONTAL_CTX_2_P = 'Frontal Ctx 2P'
    HP_ONLY = 'HP Only'
    HP_TRANSCRANIAL = 'HP Transcranial'
    INJECTION_FIBER_OPTIC_IMP = 'Injection+Fiber Optic Implant (with Headpost)'
    INJ_MOTOR_CTX = 'INJ + Motor Ctx'
    INJ_VISUAL_CTX_2_P = 'INJ + Visual Ctx 2P'
    INJ_WHC_NP_1_INJECTION_LO = 'INJ + WHC NP (1 Injection Location)'
    ISIGUIDED_INJECTION_WITH = 'ISI-guided Injection (with Headpost)'
    MOTOR_CTX = 'Motor Ctx'
    STEREOTAXIC_INJECTION = 'Stereotaxic Injection'
    STEREOTAXIC_INJECTION_WIT = 'Stereotaxic Injection (with Headpost)'
    VISUAL_CTX_2_P = 'Visual Ctx 2P'
    VISUAL_CTX_NP = 'Visual Ctx NP'
    WHC_2_P = 'WHC 2P'
    WHC_NP = 'WHC NP'
    MOTOR_CTX_2_P = 'Motor Ctx 2P'
    GRID_INJ_6_OR_9_VISUAL = 'Grid INJ (6 or 9) + Visual Ctx 2P'
    INJ_MOTOR_CTX_2_P = 'INJ + Motor Ctx 2P'
    GRID_INJ_6_OR_9_MOTOR_C = 'Grid INJ (6 or 9) + Motor Ctx 2P'
    INJ_WHC_NP = 'INJ + WHC NP'
    INJ_DHC = 'INJ+DHC'
    INJECTION_FIBER_OPTIC_IMP_ = 'Injection + Fiber Optic Implant (with Headpost)'
    STEREOTAXIC_INJECTIONS_1 = 'Stereotaxic injections: 1 INJ material'
    STEREOTAXIC_INJECTIONS_2 = 'Stereotaxic injections: 2+ INJ materials'
    EMG__ARRAY = 'EMG Array'
    TESTES__INJECTION = 'Testes Injection'
    OVIDUCT__INJECTION = 'Oviduct Injection'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Procedure from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019ImplantIdCoverslipType(str, Enum):
    """
    Enum class for ImplantIdCoverslipType
    """

    """
    allowed enum values
    """
    CUSTOM_IMPLANT_ADD_DETAIL = 'Custom Implant (add details in comments section)'
    N_2001 = '2001'
    N_2002 = '2002'
    N_3001 = '3001'
    N_5MM_STACKED_COVERSLIP = '5mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP_W = '5mm stacked coverslip (with silicone coating for Neuropixel)'
    SELECT = 'Select...'
    TS_04 = 'TS-04'
    TS_05 = 'TS-05'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019ImplantIdCoverslipType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr5VirusBiosafteyLevelBsl(str, Enum):
    """
    Enum class for Burr5 Virus Biosaftey Level (BSL).
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    BSL_1_AAV = 'BSL 1 - AAV'
    BSL_1__BEADS = 'BSL 1 - Beads'
    BSL_1_AAV__BEADS = 'BSL 1 - AAV + Beads'
    BSL_1__OTHER__WRITE_IN_CO = 'BSL 1 - Other (Write in comments)'
    BSL_2__RABIES = 'BSL 2 - Rabies'
    BSL_2_CAV = 'BSL 2 - CAV'
    BSL_2_6_OHDA = 'BSL 2 - 6-OHDA'
    BSL_2__SINDBIS = 'BSL 2 - Sindbis'
    BSL_2_HSV_1 = 'BSL 2 - HSV-1'
    BSL_2__LENTI = 'BSL 2 - Lenti'
    BSL_2__CHOLERA__TOXIN_B = 'BSL 2 - Cholera Toxin B'
    BSL_2__OTHER__WRITE_IN_CO = 'BSL 2 - Other (Write in comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr5VirusBiosafteyLevelBsl from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.las2020_list import Las2020List

class TestLas2020List(unittest.TestCase):
    """Las2020List unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Las2020List:
        """Test Las2020List
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Las2020List`
        """
        model = Las2020List()
        if include_optional:
            return Las2020List(
                accommodation_comment = '',
                acsf_time1 = '',
                acsf_time2 = '',
                acsf_time3 = '',
                acsf_time4 = '',
                acsf_time5 = '',
                acsfid1 = '',
                acsfid2 = '',
                acsfid3 = '',
                acsfid4 = '',
                acsfid5 = '',
                afternoon_pf = True,
                animals_availableon_protocol = True,
                app_author = '',
                app_editor = '',
                attachments = True,
                author = '',
                bc_age = '',
                bc_genotypes = '',
                bc_location = '',
                bc_tube = '',
                bc_type = 'Submandibular - Immunology',
                bc_volume = '',
                color_tag = '',
                compliance_asset_id = '',
                compliance_flags = '',
                compliance_tag = '',
                compliance_tag_user_id = '',
                compliance_tag_written_time = '',
                content_type = '',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                custcontact = '',
                custom_com1 = '',
                custom_com2 = '',
                custpresent = True,
                delivery_location = '156 4c',
                doc_icon = '',
                dose_route = 'Intramuscular (IM)',
                dose_sub = '',
                dose_where = '',
                doseduration = '',
                dosevolume = '',
                doxycycline = True,
                edit = '',
                editor = '',
                folder_child_count = '',
                icv_comment = '',
                icv_id1 = '',
                icv_id2 = '',
                icv_id3 = '',
                icv_id4 = '',
                icv_id5 = '',
                icv_lims = 'Stereotaxic Injections',
                icv_route1 = 'Bilateral',
                icv_route2 = 'Bilateral',
                icv_route3 = 'Bilateral',
                icv_route4 = 'Bilateral',
                icv_route5 = 'Bilateral',
                icv_sub1 = '',
                icv_sub2 = '',
                icv_sub3 = '',
                icv_sub4 = '',
                icv_sub5 = '',
                id = 56,
                is_record = '',
                item_child_count = '',
                lta_id1 = '',
                lta_id2 = '',
                lta_id3 = '',
                lta_id4 = '',
                lta_id5 = '',
                l_tdate1 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                l_tdate2 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                l_tdate3 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                l_tdate4 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                l_tdate5 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                las_comments = '',
                lims_entry = True,
                lims_project = '0310',
                lims_workflow = '2p serial Imaging',
                lims_workflow_x0020_2 = '2p serial Imaging',
                link_title = '',
                link_title_no_menu = '',
                lt_task1 = '',
                lt_task2 = '',
                lt_task3 = '',
                lt_task4 = '',
                lt_task5 = '',
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                n_end_x0020_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                n_roid1 = '',
                n_roid2 = '',
                n_roid3 = '',
                n_roid4 = '',
                n_roid5 = '',
                n_start_x0020_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                oct = True,
                post_fix = '30% Sucrose',
                project_id = '101-03-001-10 Costa PGA Lab Research (Direct)',
                project_lead2 = '',
                protocol = '2207 - In Vitro Brain Stimulation',
                qc_door_sheet = True,
                req_age1 = '',
                req_age2 = '',
                req_age3 = '',
                req_age4 = '',
                req_pro1 = 'Tissue Collection',
                req_pro2 = 'Tissue Collection',
                req_pro3 = 'Tissue Collection',
                req_pro4 = 'Tissue Collection',
                reqdate1 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reqdate2 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reqdate3 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reqdate4 = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                request_status2 = 'New',
                ro_box1 = '',
                ro_box2 = '',
                ro_box3 = '',
                ro_box4 = '',
                ro_box5 = '',
                ro_comment = '',
                ro_discard = True,
                ro_eye1 = 'Behind Either',
                ro_eye2 = 'Behind Either',
                ro_eye3 = 'Behind Either',
                ro_eye4 = 'Behind Either',
                ro_eye5 = 'Behind Either',
                ro_gc1 = '',
                ro_gc1b = '',
                ro_gc1c = '',
                ro_gc1d = '',
                ro_gc2 = '',
                ro_gc2b = '',
                ro_gc2c = '',
                ro_gc2d = '',
                ro_gc3 = '',
                ro_gc3b = '',
                ro_gc3c = '',
                ro_gc3d = '',
                ro_gc4 = '',
                ro_gc4b = '',
                ro_gc4c = '',
                ro_gc4d = '',
                ro_gc5 = '',
                ro_gc5b = '',
                ro_gc5c = '',
                ro_gc5d = '',
                ro_ice = True,
                ro_lims = 'Stereotaxic Injections',
                ro_lot1 = '',
                ro_lot1b = '',
                ro_lot1c = '',
                ro_lot1d = '',
                ro_lot2 = '',
                ro_lot2b = '',
                ro_lot2c = '',
                ro_lot2d = '',
                ro_lot3 = '',
                ro_lot3b = '',
                ro_lot3c = '',
                ro_lot3d = '',
                ro_lot4 = '',
                ro_lot4b = '',
                ro_lot4c = '',
                ro_lot4d = '',
                ro_lot5 = '',
                ro_lot5b = '',
                ro_lot5c = '',
                ro_lot5d = '',
                ro_sop = 'AF0131 Retro-orbital Injection',
                ro_spin_down = True,
                ro_sub1 = '',
                ro_sub1b = '',
                ro_sub1c = '',
                ro_sub1d = '',
                ro_sub2 = '',
                ro_sub2b = '',
                ro_sub2c = '',
                ro_sub2d = '',
                ro_sub3 = '',
                ro_sub3b = '',
                ro_sub3c = '',
                ro_sub3d = '',
                ro_sub4 = '',
                ro_sub4b = '',
                ro_sub4c = '',
                ro_sub4d = '',
                ro_sub5 = '',
                ro_sub5b = '',
                ro_sub5c = '',
                ro_sub5d = '',
                ro_tite1 = '',
                ro_tite1b = '',
                ro_tite1c = '',
                ro_tite1d = '',
                ro_tite2 = '',
                ro_tite2b = '',
                ro_tite2c = '',
                ro_tite2d = '',
                ro_tite3 = '',
                ro_tite3b = '',
                ro_tite3c = '',
                ro_tite3d = '',
                ro_tite4 = '',
                ro_tite4b = '',
                ro_tite4c = '',
                ro_tite4d = '',
                ro_tite5 = '',
                ro_tite5b = '',
                ro_tite5c = '',
                ro_tite5d = '',
                ro_tube1 = '',
                ro_tube2 = '',
                ro_tube3 = '',
                ro_tube4 = '',
                ro_tube5 = '',
                ro_vol1 = '',
                ro_vol2 = '',
                ro_vol3 = '',
                ro_vol4 = '',
                ro_vol5 = '',
                ro_vol_v1 = '',
                ro_vol_v1b = '',
                ro_vol_v1c = '',
                ro_vol_v1d = '',
                ro_vol_v2 = '',
                ro_vol_v2b = '',
                ro_vol_v2c = '',
                ro_vol_v2d = '',
                ro_vol_v3 = '',
                ro_vol_v3b = '',
                ro_vol_v3c = '',
                ro_vol_v3d = '',
                ro_vol_v4 = '',
                ro_vol_v4b = '',
                ro_vol_v4c = '',
                ro_vol_v4d = '',
                ro_vol_v5 = '',
                ro_vol_v5b = '',
                ro_vol_v5c = '',
                ro_vol_v5d = '',
                ro_where = 'LAS Drop box in Vivarium -80 freezer',
                sign_x002d_off_x0020_status = '',
                spec_deli_loc = '',
                species = 'Mouse',
                tam = True,
                tam_age = '',
                tam_freq = 'Standard 5 day dose',
                tc_prep = [
                    'Fresh Brain Dissection (SOP AF0061)'
                    ],
                tc_tiss = [
                    'Brain'
                    ],
                title = '',
                tmp = True,
                tmp_age = '',
                tmp_freq = 'Standard 3 day dose',
                ui_version_string = '',
                wellness_report_x0028_no_x002_f_ye = True,
                whereto_obtainsubstance_x0028_icv = 'LAS blue bin in Vivarium –80 freezer',
                author_id = 56,
                author_lookup_id = 56,
                editor_id = 56
            )
        else:
            return Las2020List(
        )
        """

    def testLas2020List(self):
        """Test Las2020List"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Headpost(str, Enum):
    """
    Enum class for NSB2023Headpost.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    AI_STRAIGHT_BAR = 'AI Straight bar'
    FRONTAL_CTX = 'Frontal Ctx'
    LSHAPED = 'L-shaped'
    MOTOR_CTX = 'Motor Ctx'
    VISUAL_CTX = 'Visual Ctx'
    WHC_FULL_RING = 'WHC (Full ring)'
    WHC_NP_ZIRCONIA = 'WHC NP (Zirconia)'
    WHC_NP = 'WHC NP'
    WHC_2P = 'WHC 2P'
    LC = 'LC'
    DHC = 'DHC'
    OTHER_ADD_DETAILS_IN_REQU = 'Other (add details in requestor comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Headpost from a JSON string"""
        return cls(json.loads(json_str))


